################################################################
# Code to create the figures in Gilbert and Sun (2014, JRSS C)
#
# Run the program cmprskPHContinMark for 2 distances: kwong.cm
# and kwong.92
#
# Then the following code will produce 4 plots, where plots 2-4
# are identical to Figures 1-3 in Gilbert and Sun (2014, JRSS C)
################################################################
cmprskPHContinMark_makeplots <- function(
    datafile_cm =system.file("extdata","practicedataRV144_92.dat",         package="cmprskPHContinMark"),
    datafile_92 =system.file("extdata","practicedataRV144_cm.dat",         package="cmprskPHContinMark"),
    vefile_92   =system.file("extdata","VAC144A1h3Pmindist.kwong.92_VE",   package="cmprskPHContinMark"),
    vefile_cm   =system.file("extdata","VAC144A1h3Pmindist.kwong.cm_VE",   package="cmprskPHContinMark"),
    plot1file_92=system.file("extdata","VAC144A1h3Pmindist.kwong.92_Plot1",package="cmprskPHContinMark"),
    plot1file_cm=system.file("extdata","VAC144A1h3Pmindist.kwong.cm_Plot1",package="cmprskPHContinMark"),
    plot2file_92=system.file("extdata","VAC144A1h3Pmindist.kwong.92_Plot2",package="cmprskPHContinMark"),
    plot2file_cm=system.file("extdata","VAC144A1h3Pmindist.kwong.cm_Plot2",package="cmprskPHContinMark")
) {
   mat <- matrix(scan(datafile_cm),ncol=8,byrow=T)
   trt <- mat[,4]
   V <- mat[,8]
   keep <- V<=1 & mat[,7]==1
   grp <- trt+1
   keep3 <- V>0
   ylimskwongcm <-c(min(V[keep])-.02,max(V[keep])+.02)

   mat <- matrix(scan(datafile_92),ncol=8,byrow=T)
   trt2 <- mat[,4]
   V2 <- mat[,8]
   keep2 <- V2<=1 & mat[,7]==1
   grp2 <- trt2+1
   keep4 <- V2>0
   time32 <- mat[,6]
   ylimskwong92 <-c(min(V2[keep2])-.02,max(V2[keep2])+.02)

   ylims <- c(0,max(c(round(ylimskwong92,2),round(ylimskwongcm,2))))

   # boxplots (bonus plot, not included in Gilbert and Sun)
   postscript("Figure1markmissingtestingmindistkwong.92cm_boxplots.eps",horizontal=FALSE)
   par(mfrow=c(1,2),cex.main=1.4,cex.axis=1.2,cex.lab=1.2,las=1,oma=c(1,1,4,1))
   boxplot(V2[keep2]~grp2[keep2],names=c("Placebo","Vaccine"),
   ylab="HIV sequence distances",ylim=ylims,
   main="92TH023 reference",outline=FALSE)
   points(jitter(as.numeric(grp2[keep2 & keep4])),V2[keep2 & keep4])
   points(grp2[keep2 & !keep4],V2[keep2 & !keep4])

   boxplot(V[keep]~grp[keep],names=c("Placebo","Vaccine"),
   ylab="HIV sequence distances",ylim=ylims,
   main="CM44 reference",outline=FALSE)
   points(jitter(as.numeric(grp[keep & keep3])),V[keep & keep3])
   points(grp[keep & !keep3],V[keep & !keep3])

   mtext("Monoclonal antibody contact site gp120 distances",cex=1.8,outer=T)
   dev.off()

   # Scatterplots (marks versus the observed failure times)
   #ylims <- c(min(c(range(V2[keep2]),range(V[keep2])))-.02, max(c(range(V2[keep2]),range(V[keep2])))+.02)

   #ylims=c(0,1)
   #V[keep] <- (V[keep] - min(V[keep]))/(max(V[keep]) - min(V[keep]))
   #V2[keep2] <- (V2[keep2] - min(V2[keep2]))/(max(V2[keep2]) - min(V2[keep2]))

   postscript("Figure1markmissingtestingmindistkwong.92cm_scatterplots.eps",horizontal=FALSE)
   par(mfrow=c(1,2),cex.main=1.4,cex.axis=1.2,cex.lab=1.2,las=1,oma=c(9,3,9,3))
   plot(time32[keep2 & grp2==2],V2[keep2 & grp2==2],
   ylab="HIV Sequence Distance",ylim=ylims,
   xlab="HIV Infection Time T (Years)",xlim=c(-0.02,4.0),col="blue",pch="v",
   main="92TH023 reference",cex=1.3)
   lines(lowess(time32[keep2 & grp2==2],V2[keep2 & grp2==2]),col="blue",cex=1.4,lwd=2.3,lty=1)
   points(time32[keep2 & grp2==1],V2[keep2 & grp2==1],
   ylab="HIV Sequence Distance",
   xlab="HIV Infection Time T (Years)",pch="p",col="black",
   main="92TH023 reference",cex=1.3)
   legend(x="bottomright",col=c("blue","black"),lty=c(1,2),lwd=1.4,legend=c("Vaccine","Placebo"),cex=1.4)
   lines(lowess(time32[keep2 & grp2==1],V2[keep2 & grp2==1]),col="black",cex=1.4,lwd=2.3,lty=2)

   plot(time32[keep & grp==2],V[keep & grp==2],
   ylab="HIV Sequence Distance",ylim=ylims,
   xlab="HIV Infection Time T (Years)",xlim=c(-0.02,4.0),col="blue",pch="v",
   main="CM244 reference",cex=1.3)
   lines(lowess(time32[keep & grp==2],V[keep & grp==2]),col="blue",cex=1.4,lwd=2.3,lty=1)
   points(time32[keep & grp==1],V[keep & grp==1],
   ylab="HIV Sequence Distance",
   xlab="HIV Infection Time T (Years)",pch="p",col="black",
   main="CM244 reference",cex=1.3)
   legend(x="bottomright",col=c("blue","black"),lty=c(1,2),lwd=1.4,legend=c("Vaccine","Placebo"),cex=1.4)
   lines(lowess(time32[keep & grp==1],V[keep & grp==1]),col="black",cex=1.4,lwd=2.3,lty=2)

   mtext("Contact site gp120 distances versus HIV infection times",cex=1.5,outer=T)
   dev.off()

   postscript("RV144_VECI_A1h3P_mindist_kwong.92cm.eps",horizontal=FALSE)

   par(mfrow=c(1,2),mar=c(4.1,4.1,4.1,2.1),cex.axis=1.1,cex.lab=1.1,cex.main=1.4,las=1,oma=c(1,1,4,1))  
   VAC144_VE_A0<-matrix(scan(vefile_92,skip=2),ncol=9,byrow=T)

   v144<-VAC144_VE_A0[,1]
   VE<-VAC144_VE_A0[,8]
   VESE<-VAC144_VE_A0[,9]
   # 95% Confidence Interval of VE(v) 
   VElow<-VE-1.96*VESE
   VEup<-VE+1.96*VESE

   zero<-VE*0

   plot(v144,VE,xlab=" ",ylab="", lwd=2,lty=1,
   xlim=c(0,1),ylim=c(-0.8,1.0),axes=F,type='n')
   lines(v144,VE,lwd=2)
   lines(v144,VElow,type="l",col="blue",lwd=1.4,lty=2)
   lines(v144,VEup,type="l",col="blue",lwd=1.4,lty=2)
   lines(v144,zero,type="l",col="gray",lwd=1)

   axis(2,at=c(-0.8,-0.4,0,0.25,0.5,0.75,1.0),labels=c(-80,-40,0,25,50,75,100))
   axis(1,at=c(0,.333,0.666,1.0),labels=round(seq(ylimskwong92[1]+0.02,ylimskwong92[2]-0.02,len=4),2))
   mtext("v", at=0.5, line=3, side=1,cex=1.5)
   mtext("Estimate of VE(v)",line=4,side=2,cex=1.5,las=0)
   title("92TH023 reference")

   VAC144_VE_A0<-matrix(scan(vefile_cm,skip=2),ncol=9,byrow=T)

   v144<-VAC144_VE_A0[,1]
   VE<-VAC144_VE_A0[,8]
   VESE<-VAC144_VE_A0[,9]
   # 95% Confidence Interval of VE(v) 
   VElow<-VE-1.96*VESE
   VEup<-VE+1.96*VESE

   zero<-VE*0

   plot(v144,VE,xlab=" ",ylab="", lwd=2,lty=1,
   xlim=c(0,1),ylim=c(-0.8,1.0),axes=F,type='n')
   lines(v144,VE,lwd=2)
   lines(v144,VElow,type="l",col="blue",lwd=1.4,lty=2)
   lines(v144,VEup,type="l",col="blue",lwd=1.4,lty=2)
   lines(v144,zero,type="l",col="gray",lwd=1)

   axis(2,at=c(-0.8,-0.4,0,0.25,0.5,0.75,1.0),labels=c(-80,-40,0,25,50,75,100))
   axis(1,at=c(0,.333,0.666,1.0),labels=round(seq(ylimskwongcm[1]+0.02,ylimskwongcm[2]-0.02,len=4),2))
   mtext("v", at=0.5, line=3, side=1,cex=1.5)
   mtext("Estimate of VE(v)",line=4,side=2,cex=1.5,las=0)
   title("CM244 reference")

   mtext("Estimated VE(v) for two gp120 distances",outer=T,cex=1.8)

   dev.off()

   postscript("RV144_TestProcs_A1h3P_kwong_92cm.eps",horizontal=FALSE)
   par(las=1,mfrow=c(2,2),mar=c(4.1,4.1,4.1,4.1),cex.axis=1.3,cex.lab=1.3,cex.main=1.4,oma=c(1,1,4,1))
   #
   VAC144_Plot1<-matrix(scan(plot1file_92,skip=1),ncol=22,byrow=T)
   v144<-VAC144_Plot1[,1]
   Proc1<-VAC144_Plot1[,2]
   ## new code/peter/04/10/14
   ylimstp <- c(min(VAC144_Plot1),max(VAC144_Plot1))
   rn <- ylimstp[2]-ylimstp[1]
   ylimstp[1] <- ylimstp[1] - rn*.03
   ylimstp[2] <- ylimstp[2] + rn*.03

   plot(v144,Proc1,xlab="v",ylab="Test process",xlim=c(0,1),ylim=ylimstp,axes=F,type='n')
   #plot(v144,Proc1,xlab="v",ylab="Test process",xlim=c(0,1),ylim=c(-100,100),axes=F,type='n')

   for (i in 1:20) {lines(v144,VAC144_Plot1[,i+2],lwd=.5,col="grey") }
   lines(v144,Proc1,lwd=2.3)
   
   ## change/peter/04-12-14
   #axis(1,at=c(0,.3333,66666,1),labels=seq(ylimskwong92[1]+0.02,ylimskwong92[2]-0.02,len=4))
   #axis(2,at=c(-100,-75,-50,-25,0,25,50,75,100),labels=c(-100,-75,-50,-25,0,25,50,75,100))
   
   axis(1,at=c(0,.3333,66666,1),labels=round(seq(ylimskwong92[1]+0.02,ylimskwong92[2]-0.02,len=4),2))
   axis(2)

   title("(a) H_10: VE(v)=0 [92TH023]")
   #
   VAC144_Plot1<-matrix(scan(plot1file_cm,skip=1),ncol=22,byrow=T)
   v144<-VAC144_Plot1[,1]
   Proc1<-VAC144_Plot1[,2]
   
   ## New code/peter/04-12-14
   ylimstp <- c(min(VAC144_Plot1),max(VAC144_Plot1))
   rn <- ylimstp[2]-ylimstp[1]
   ylimstp[1] <- ylimstp[1] - rn*.03
   ylimstp[2] <- ylimstp[2] + rn*.03

   plot(v144,Proc1,xlab="v",ylab="Test process",xlim=c(0,1),ylim=ylimstp,axes=F,type='n')
   #plot(v144,Proc1,xlab="v",ylab="Test process",xlim=c(0,1),ylim=c(-100,100),axes=F,type='n')
   ##

   for (i in 1:20) {lines(v144,VAC144_Plot1[,i+2],lwd=.5,col="grey") }
   lines(v144,Proc1,lwd=2.3)
   ## change/peter/04-12-14
   #axis(1,at=c(0,.3333,.66666,1),labels=seq(ylimskwongcm[1]+0.02,ylimskwongcm[2]-0.02,len=4))
   #axis(2,at=c(-100,-75,-50,-25,0,25,50,75,100),labels=c(-100,-75,-50,-25,0,25,50,75,100))
   axis(1,at=c(0,.3333,.66666,1),labels=round(seq(ylimskwongcm[1]+0.02,ylimskwongcm[2]-0.02,len=4),2))
   axis(2)
   ##

   title("(b) H_10: VE(v)=0 [CM244]")

   VAC144_Plot2<-matrix(scan(plot2file_92,skip=2),ncol=22,byrow=T)
   v144<-VAC144_Plot2[,1]
   Proc2<-VAC144_Plot2[,2]
   ##code change/peter/4-11-14 
   ylimstp <- c(min(VAC144_Plot2),max(VAC144_Plot2))
   rn <- ylimstp[2]-ylimstp[1]
   ylimstp[1] <- ylimstp[1] - rn*.03
   ylimstp[2] <- ylimstp[2] + rn*.03

   plot(v144,Proc2,xlab="v",ylab="Test process",xlim=c(0,1),ylim=ylimstp,axes=F,type='n')
   #plot(v144,Proc2,xlab="v",ylab="Test process",xlim=c(0,1),ylim=c(-100,100),axes=F,type='n')
   for (i in 1:20) {lines(v144,VAC144_Plot2[,i+2],lwd=.5,col="grey") }
   lines(v144,Proc2,lwd=2.3)
   axis(1,at=c(0,.3333,.66666,1),labels=round(seq(ylimskwong92[1]+0.02,ylimskwong92[2]-0.02,len=4),2))
   axis(2)
   #axis(1,at=c(0,.3333,.66666,1),labels=seq(ylimskwong92[1]+0.02,ylimskwong92[2]-0.02,len=4))
   #axis(2,at=c(-100,-75,-50,-25,0,25,50,75,100))

   title("(c) H_20: VE(v)=VE [92TH023]")

   VAC144_Plot2<-matrix(scan(plot2file_cm,skip=2),ncol=22,byrow=T)
   v144<-VAC144_Plot2[,1]
   Proc2<-VAC144_Plot2[,2]
   ##New code/peter/04-11-2014
   ylimstp <- c(min(VAC144_Plot2),max(VAC144_Plot2))
   rn <- ylimstp[2]-ylimstp[1]
   ylimstp[1] <- ylimstp[1] - rn*.03
   ylimstp[2] <- ylimstp[2] + rn*.03

   plot(v144,Proc2,xlab="v",ylab="Test process",xlim=c(0,1),ylim=ylimstp,axes=F,type='n')
   #plot(v144,Proc2,xlab="v",ylab="Test process",xlim=c(0,1),ylim=c(-100,100),axes=F,type='n')

   for (i in 1:20) {lines(v144,VAC144_Plot2[,i+2],lwd=.5,col="grey") }
   lines(v144,Proc2,lwd=2.3)
   axis(1,at=c(0,.3333,.66666,1),labels=round(seq(ylimskwongcm[1]+0.02,ylimskwongcm[2]-0.02,len=4),2))
   axis(2)
   #axis(1,at=c(0,.3333,.66666,1),labels=seq(ylimskwongcm[1]+0.02,ylimskwongcm[2]-0.02,len=4))
   #axis(2,at=c(-100,-75,-50,-25,0,25,50,75,100))
   ## 
   title("(d) H_20: VE(v)=VE [CM244]")

   mtext("Test processes for testing any VE and mark-varying VE(v)",outer=T,cex=1.6)

   dev.off()
}
