cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c     This program implements Sun and Gilbert (2012, Scand J Statistics) and
c     Gilbert and Sun (2014, Journal of the Royal Statistical Society Series C), to analyze
c     an input data-set.
c
c     These papers provide estimation and testing methods for the mark-specific proportional hazards
c     model accommodating that some failures have a missing mark, and allowing separate
c     baseline mark-specific hazard functions for different baseline subgroups.
c     Missing marks are handled via
c     inverse-probability weighting (IPW) or augmented IPW.
c
c This version of the code only handles a special case where the auxiliary for 
c association with the mark variable V is binary; and the failure time is the variable for  
c predicting whether a case has the mark V available.  These parts of the program would 
c need to be changed manually for other types of auxiliary covariates.
c The relevant code is surrounded by the comments AUXILIARY CODE
c 
c   December, 2013
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c   Test statistics for H_{10}: VE(v)=0 are calculated for the mark v over [a1,b1], 0<a1<b1=<1
c   Test statistics for H_{20}: VE(v)=VE are calculated for the mark over [a2,b1], a2>a1    
cc**************************************************************

      subroutine cmprskPHContinMark(inputf,outpre,nboot,missmark,
     $ nauxiliary,tau,tband,hband,a0,b1,ntgrid,nvgrid)
c
c Parameters:
c     Name of the input file
      character*255 inputf
c     Prefix for output file names
      character*255 outpre  
c     number of bootstrap iterations
      integer nboot
c     flags
      integer MissMark,Nauxiliary
c 
c     tau is the end of the follow-up period for conducting the analysis
c     TBAND = h_1 in Gilbert and Sun (2014, Figure 3 caption)
c     hband = h_2 = h in Gilbert and Sun (2014, Figure 3 caption)
c     a0 = a in Gilbert and Sun (2014, Figure 3 caption) 
c     b1 = b in Gilbert and Sun (2014, figure 3 caption)
      real tau,tband,hband,a0,b1
c     grid sizes
      integer ntgrid,nvgrid

c    fits a continuous mark-specific PH model with time-dependent covariates
c    and with a baseline stratification variable (may have only 1 stratum).

c     make sure the following dims agree with the dims
c     in the subroutine estpvry; that is, always set
c     mxn=nsamp, mcov=ncov
c     mxkk is the maximum number of strata.
c     mxb is the bootstrap size.

c Use same hard-coded sample size for all subroutines.
      parameter(mxn=20000,mcov=1,mcovR=2,mcovG=4,mxv=200,
     $ mxb=500,mxkk=1,mxtgrid=100)
c Ted: These should be input parameters, at least mxn, mxb, mxv, mxtgrid       

c    The following inputs are needed:
c      nvgrid: number of gridpoints for \beta(v)
c      ncov  : number of covariates
c      nsamp(ks) : sample size for the ks-th strata
c      time(ks,i)  :  failure time for subject i in ks-th strata
c      censor(ks,i) : indicator of noncensorship
c      covart(ks,j,i,k) :  covariate j for subject i at the k-th failure time
c      mark(ks,i):  mark value for subject i in ks-th strata

c     $ cenrat,vstep, vspot, hband,alpha,bet,


      real time(mxkk,mxn),censor(mxkk,mxn),deltak(mxkk,mxn),
     $ covart(mxkk,mcov,mxn,1),mark(mxkk,mxn),Ax(mxkk,mxn),
     $ R(mxkk,mxn),U(mcov),U2(mcov),s0(mxn),s1(mcov,mxn),
     $ s2(mcov,mcov),F(mcov,mcov),beta(mcov), var(mcov,mcov),
     $ betav(mcov),ekconst,vestar,covartR(mxkk,mcovR,mxn),
     $ psiR(mxkk,mcovR),psiRvar(mxkk,mcovR,mcovR), wght(mxkk,mxn),
     $ psiRse(mxkk,mcovR),
     $ covartG(mxkk,mcovG,mxn),psiG(mxkk,mcovG),psiGse(mxkk,mcovG),
     $ psiGvar(mxkk,mcovG,mcovG), varcom(mcov,mcov),betacom0(mcov),
     $ secom(mcov,mxv),betacom(mcov,mxv),varipw(mcov,mcov),
     $ betaipw0(mcov),seipw(mcov,mxv),betaipw(mcov,mxv),
     $ varaug(mcov,mcov),betaaug0(mcov),
     $ seaug(mcov,mxv),betaaug(mcov,mxv),
     $ LAMBDA0(mxkk,mxn),LAMBDAk0(mxkk,mxtgrid),CLAMBDAIPW(mxkk,mxn),
     $ LAMBDAIPW(mxkk,mxn,mxv),DRHOipw(mxkk,mxn),
     $ CUMB1(0:mxv),betaofv(mcov,mxv),sigmaInv(mcov,mcov,mxv),
     $ Lamktv0(mxkk,mxtgrid,mxv), zdev(mxkk,mxn),CLAMBDAUG(mxkk,mxn),
     $ LAMBDAUG(mxkk,mxn,mxv),CUMBDIST(mcov,0:mxv),CUMB1x(mxv),
     $ CUMB1se(mxv),CKLAMBDAIPW(mxkk,mxn,mxv),cBproc1(0:mxv),
     $ cBproc2(0:mxv),BootDist(mxb,mxv),cBproc1x(0:mxv),cBproc2x(0:mxv),
     $ betacox(mcov),varcox(mcov,mcov),
     & sigtemp(mcov,mcov),AsigInv(mcov,mcov,mxv,mxv),
     & tempaug(mxkk,mxn,mxv),S0N(mxkk,mxn,mxv),S1N(mcov,mxkk,mxn,mxv),
     & bzt(mxn,1),DRHOaug(mxkk,mxn),cBproc1s(mxv,20),cBproc2s(mxv,20),
     & beta1lw(mxv),beta1up(mxv),veest(mxv),vese(mxv),
     & gender(mxn),trt(mxn),censtus(mxn),timeInfc(mxn),obsR(mxn),
     & vV(mxn), G(mxkk,mxn,mxv), dat(8),cenG(mxkk,mxn),a0new,mn,mx

      integer kk,ks,nsamp(mxkk),nsampa,ncov,ncovt,iskip,iskip0,
     $seeda,seedb,seedc,seedd,iskipa1,iskipa2,nvgrid1,
     $nsim,nplaceb,ibruce

      character*255 vef,pof,pl1,pl2

c Sanity checks
      if(nboot.gt.mxb) then
         print *,'nboot currently',nboot,'must be less than or equal to'
     &           ,mxb
         return
      endif
   
      if(nvgrid.gt.mxv) then
         print *,'nvgrid currently',nvgrid,
     &         'must be less than or equal to',mxv
         return
      endif

      if(ntgrid.gt.mxtgrid) then
         print *,'ntgrid currently',ntgrid,
     &         'must be less than or equal to',mxtgrid
         return
      endif
   

c Read in the data file
      open(11,file=inputf)

c      open (33,file='VAC144A0h5P_Beta')
c
c     Generate file names from prefix

      vef = trim(outpre) // '_VE'
      pof = trim(outpre) // '_Power'
      pl1 = trim(outpre) // '_Plot1'
      pl2 = trim(outpre) // '_Plot2'

      open (66,file=vef)
      open (44,file=pof)
      open (22,file=pl1)
      open (25,file=pl2)


      iseeda= 62648
      iseedb= 85236
      call setall(iseeda, iseedb)

c*****************************************************************************
c     Estimation and Hypothesis tests for Mark PH model with missing marks
c
c*****************************************************************************


      nsim=1

      a0new=1.
      item=0
      ibruce=0
      mx=0.
      mn=1.
 2     read(11,*,end=3)(dat(i),i=1,8)
      item=item+1
      if(item.gt.mxn) then
         print *,'Too many data items! More than',mxn
         return
      endif
      ibruce=ibruce+1
      gender(item)=dat(3)
      trt(item)=dat(4)
      censtus(item)=dat(5)
      timeInfc(item)=dat(6)
      obsR(item)=dat(7)
      if(censtus(item).le.0.5)then
         obsR(item)=1.0
      endif
      vV(item)=dat(8)
      if ((censtus(item).ge.0.5).and.(obsR(item).ge.0.5) 
     # .and. (dat(8).lt.mn)) then 
         mn=dat(8)
      endif
      if ((censtus(item).ge.0.5).and.(obsR(item).ge.0.5) 
     # .and. (dat(8).gt.mx)) then 
         mx=dat(8)
      endif
      if (dat(8).lt.a0new)then
        a0new=dat(8)
      endif
c IMPORTANT NOTE
c This version of the code inputs V on its own scale, and re-scales it to 0-1 before doing the analysis.
      go to 2
 3    continue      
c
      close(11)
c Put the marks on the scale 0 to 1:
      write (6,*) "mn,mx=",mn,mx
      do 4 i=1,ibruce
      if((censtus(i).ge.0.5).and.(obsR(i).ge.0.5))then
      vV(i)=(vV(i)-mn)/(mx-mn)
      write (6,*) "i,vV(i)=",i,vV(i)
      end if
 4    continue

c     kk is the number of strata
      kk=1
      nsamp(1)=item
      ncov=1
      print*,'nsamp= ', nsamp(1)

      rinfect1=0.0
      rinfect0=0.0
      do i=1,nsamp(1)
        if((censtus(i).ge.0.5).and.(trt(i).ge.0.5))then
           rinfect1=rinfect1+1.0
        endif
      if((censtus(i).ge.0.5).and.(trt(i).le.0.5))then
          rinfect0=rinfect0+1.0
      endif
      enddo

      nsampa=0
      do ks=1,kk
       nsampa=nsampa+nsamp(ks)
      enddo
       rnsamp=float(nsampa)


c*****************************************************************************
c                      Set up the smoothing parameters
c
c*****************************************************************************


      tstep=tau/float(ntgrid)

      vstep=1.0/float(nvgrid)


      iskip=a0/vstep

c       write(6,*) 'a0new=',a0new

c    Epanechnikov kernel has squared integral = 3/5 !
      ekconst=3./5.

c     calculate the test statistics for H_{10}:VE(v)=0 for v over [a1,b1], 0<a1<b1=<1
c     calculate the test statistics for H_{20}:VE(v)=VE for v over [a2,b1], a2>a1 >=a0

       a1=a0+vstep
c a1 = a' in Gilbert and Sun (2014, figure 3 caption)
       a2=a1+2.0*vstep

       write(6,*) "a0,a1,a2 (lower bounds of V) =",a0,a1,a2

c*****************************************************************************
c                     Set up the control parameters
c
c     For the procedures without missing marks, set MissMark=0;
c     For the procedures with missing marks, set MissMark=1.
c      (MissMark=0) corresponds to setting R(ks,i)=1 and wght(ks,i)=1.
c
c     For the procedure without using the auxiliary marks, set Nauxiliary=0;
c        to use the auxiliary marks, set Nauxiliary=1.
c*****************************************************************************



c Default: MissMark = 1
c Default: Nauxiliary = 1
c Nauxiliary is only relevant if there are missing marks.


c*****************************************************************************


      write(44,*)'  '
      write(44,*)'iseeda, iseedb= ', iseeda, iseedb
      write(44,*)'  '

      write(44,*)'MissMark?= ', MissMark

      write(44,*)'Nauxiliary?= ', Nauxiliary

      write(44,*)'  '
      write(44,*)' Sample Sizes: '
      write(44,*) ' nboot= ',nboot, ', nsamp= ',(nsamp(ks),ks=1,kk)

      write(44,*)'                       '
      write(44,*)' Smoothing Parameters: '
      write(44,*)' hband= ',hband,', nvgrid= ',nvgrid,', vstep= ',vstep,
     & ', iskip= ',iskip 

      write(44,*) ' TBAND= ',TBAND,' tau= ', tau, ' ntgrid= ',ntgrid
      write(44,*) '                '
      write(44,*) 'a1= ',a1, 'b1= ',b1, 'a2= ', a2
      write(44,*) '                '
      write(44,*) ' *********************************** '
      write(44,*) '                '



c***************************************************************************
c     Read data into the designed variables
c
c***************************************************************************
 
    
      sumdelta=0.0
      Rsum=0.0

      do 2000 isim=1,nsim

       do ks=1,kk
       do i=1,nsamp(ks)
         do j=1,ncov
               covart(ks,j,i,1)=trt(i)
         enddo
         time(ks,i)=timeInfc(i)
         censor(ks,i)=censtus(i)
         mark(ks,i)=vV(i)
         Ax(ks,i)=gender(i)
         R(ks,i)=obsR(i)

         sumdelta=sumdelta+censor(ks,i)
         Rsum=Rsum+R(ks,i)*censor(ks,i)
       enddo
       enddo

c      do i=1,5
c      print*, '1st obs =',
c     $  Ax(1,i),covart(1,1,i,1),censor(1,i),time(1,i),R(1,i),mark(1,i)
c      enddo

c*****************************************************************************
c     Calculate the probability of nonmissing marks.
c
c*****************************************************************************

ccccc     wght(ks,i) can be calculated using an external program

c      setup the covariates for logit regression for R:
       ncovR=1+1
       do ks=1,kk
       do i=1,nsamp(ks)
         covartR(ks,1,i)=1.0
         covartR(ks,2,i)=time(ks,i)
       enddo
       enddo

      if(MissMark.eq.0)then
        do ks=1,kk
        do i=1,nsamp(ks)
          R(ks,i)=1.0
          wght(ks,i)=1.0
        enddo
        enddo
       else
       print *,"calling estplogit"
       call estplogit(kk,nsamp,ncovR,covartR,R,censor,psiR,psiRvar)
       print *,"called estplogit" 
        do ks=1,kk
        do j=1,ncovR
            psiRse(ks,j)=sqrt(psiRvar(ks,j,j))
        enddo
        enddo
        print *, ' psiR= ', psiR, ' psiRse= ', psiRse
 
      do 185 ks=1,kk
      do 180 i=1,nsamp(ks)
          ei=covartR(ks,1,i)*psiR(ks,1)+covartR(ks,2,i)*psiR(ks,2)
          phi=exp(ei)/(1.0+exp(ei))
          wght(ks,i)=R(ks,i)/(censor(ks,i)*phi+1.0-censor(ks,i))
 180  continue
 185  continue
      endif
ccccc     the end of calculating wght(ks,i)



c****************************************************************************
c     Calculate the pdf G(ks,i,ispot) for the second stage estimator, aipw
c
c****************************************************************************

ccccc IF use (Nauxiliary.eq.1), 
ccccc the pdf G(ks,i,ispot) can also be calculated using an external program

c This version of the code only handles a special case where the auxiliary for 
c association with the mark variable V is binary; and the failure time is the variable for  c predicting whether a case has the mark V available.  These parts of the program would 
c need to be changed manually for other types of auxiliary covariates.
c The relevant code is surrounded by the comments AUXILIARY CODE

c AUXILIARY CODE
c      gender is the only significant variable for the mark.
c      We set gender as the only auxliary variable.
c      Since gender is a binary variable, do the logistic regression
c      of A(gender) ~ V,T,Z .
c
c      In addition, the time is the only significant variable for predicting
c      the probability of missingness.
c      We use the logistic regression of R ~ T.


c      setup the covariates for logistic regression for gender to calculate g(a|w):
       ncovG=3+1
       do ks=1,kk
       do i=1,nsamp(ks)
         covartG(ks,1,i)=1.0
         covartG(ks,2,i)=time(ks,i)
         covartG(ks,3,i)=covart(ks,1,i,1)
         covartG(ks,4,i)=mark(ks,i)
c      based on obs with both censor and R equal to 1
         cenG(ks,i)=censor(ks,i)*R(ks,i)
       enddo
       enddo

      IF (Nauxiliary.eq.1) THEN
      call estplogit(kk,nsamp,ncovG,covartG,Ax,cenG,psiG,psiGvar)
        do ks=1,kk
        do j=1,ncovG
            psiGse(ks,j)=sqrt(psiGvar(ks,j,j))
        enddo
        enddo
        print *, ' psiG= ', psiG, ' psiGse= ', psiGse

      do 265 ks=1,kk
      do 260 i=1,nsamp(ks)
         ei=0.
         do j=1,ncovG-1
           ei=ei+covartG(ks,j,i)*psiG(ks,j)
         enddo
         do ispot=1,nvgrid
            vspot= float(ispot)*vstep
            phi=exp(ei+psiG(ks,4)*vspot)/(1.0+exp(ei+psiG(ks,4)*vspot))
            G(ks,i,ispot)=phi*Ax(ks,i)+(1.-phi)*(1-Ax(ks,i))
c            G(ks,i,ispot)=censor(ks,i)*(phi*Ax(ks,i)+(1.-phi)
c     &                    *(1-Ax(ks,i)))
         enddo
 260  continue
 265  continue
      ENDIF

      IF (Nauxiliary.eq.0) THEN
      do 275 ks=1,kk
      do 270 i=1,nsamp(ks)
         do ispot=1,nvgrid
            vspot= float(ispot)*vstep
c            G(ks,i,ispot)=censor(ks,i)
            G(ks,i,ispot)=1.0
         enddo
 270  continue
 275  continue
      ENDIF

ccccc the end of calculating G(ks,i,ispot).
c AUXILIARY CODE


c   ********************************************************************
c               Estimation of the \beta(v) at each mark v  
c
c   ********************************************************************


c
c    ********** COMPARISON WITH STANDARD PH MODEL ANALYSIS **********
c    Also serve as an initial value for the mark-specific PH model

c    *** CALL COX SUBROUTINE ***
        kl=10
        betacox(1)=-0.7
        do 1500 k=1,Kl
        call estpvry(tau,kk,nsamp,ncov,time,covart,censor,censor,
     $  betacox,varcox)
 1500   continue

cc    estimate of s.e. of \hat\beta:
          seph=sqrt(varcox(1,1))
cc    Wald test for $\beta=0$:
         Tw=betacox(1)/seph

      write(44,*)'Est of beta and Var under Cox model: ', betacox,varcox
      write(44,*)'Est & SE of beta(1) under Cox model: ',betacox(1),seph
      write(44,*)'Wald test statistic for testing beta(1)=0: ', Tw

      write(44,*)'                '
      write(44,*)' *************************************************** '

      write(44,*) '                       '
      write(44,*) ' The logisitic regression outputs: '
      write(44,*) ' psiR= ', psiR, ' psiRse= ', psiRse
      write(44,*) ' psiG= ', psiG, ' psiGse= ', psiGse

c   ********************************************************************
c      uniker is (1/h)K((t_k-t)/h) \delta where K is uniform kernel
c      normker is (1/h)K((t_k-t)/h) \delta where K is normal kernel
c   ********************************************************************

       do j=1,ncov
         betacom0(j)=betacox(j)
       enddo


      do 250 ispot=1,nvgrid
c*** re
         vspot=float(ispot)*vstep

       do 200 ks=1,kk
       do 200 i=1,nsamp(ks)
c        deltak(ks,i)=uniker(mark(ks,i),vspot,hband,censor(ks,i))
c        deltak(ks,i)=normker(mark(ks,i),vspot,hband,censor(ks,i))
         deltak(ks,i)=Epanker(mark(ks,i),vspot,hband,censor(ks,i))
 200   continue


c   ********************************************************************
c                 Complete data likelihood estimator:  complete
c
c   ********************************************************************

c    set the weight wght(ks,i)=R(ks,i) to get the complete data likelihood estimator:

        call estpcom(tau,kk,nsamp,ncov,time,covart,censor,deltak,
     $  R,betacom0,F,varcom)

       do j=1,ncov
        betacom(j,ispot)=betacom0(j)
        secom(j,ispot)=sqrt(varcom(j,j))
       enddo
c     print*, 'betacom = ', vspot, betacom(1,ispot), secom(1,ispot)

c   ********************************************************************
c                The inverse probability weighted estimator:  ipw
c
c   ********************************************************************

       do j=1,ncov
         betaipw0(j)=betacom(j,ispot)
       enddo

        call estpipw(tau,kk,nsamp,TBAND,ncov,time,covart,censor,deltak,
     $  wght,betaipw0,LAMBDA0,F,varipw)

       do j=1,ncov
        betaipw(j,ispot)=betaipw0(j)
        seipw(j,ispot)=sqrt(varipw(j,j))
       enddo
c       print*, 'betaipw = ', vspot, betaipw(1,ispot), seipw(1,ispot)
 250  continue


c   ********************************************************************
c                         second stage estimator:   aipw
c   ********************************************************************


c    Need to set the following initial value:
      do  ks=1,kk
        do  i=1,nsamp(ks)
          CLAMBDAIPW(ks,i)=0.0
        enddo
      enddo

      do 500 ispot=1,nvgrid
c*** re: delete a+
       vspot=float(ispot)*vstep

C      CALCULATE CLAMBDA(KS,I)= $\int_0^1 \lambda_k(t,u|z) h_k(a|t,u,z) du$ AT $W_{ki}=(T_{ki},Z_{ki})$:
       DO 300 KS=1,KK
       DO 280 I=1,NSAMP(KS)
         if ((time(ks,i).le.tau).and.(censor(ks,i).gt.0.5)) then
         BZIPW=0.0
         DO J=1,NCOV
            BZIPW=BZIPW+BETAIPW(J,ispot)*COVART(KS,J,I,1)
         ENDDO
          LAMBDAIPW(KS,I,ISPOT)=LAMBDA0(KS,I)*EXP(BZIPW)

              CLAMBDAIPW(KS,I)=CLAMBDAIPW(KS,I)+LAMBDA0(KS,I)*EXP(BZIPW)
     $                      *G(ks,i,ispot)*VSTEP
          
         endif
  280 CONTINUE
  300 CONTINUE
  500 CONTINUE

c       print*,' CLAMBDAIPW= ', CLAMBDAIPW
c       print*,'LAMBDAIPW(1,6,10), CLAMBDAIPW(1,6)= ',
c     $          LAMBDAIPW(1,6,10), CLAMBDAIPW(1,6)

C      CALCULATE CKLAMBDA(KS,I)= $\int_0^1 K_h(u-v) \lambda_k(t,u|z) h_k(a|t,u,z) du$ AT $W_{ki}=(T_{ki},Z_{ki})$:

       DO 490 KS=1,KK
       DO 480 I=1,NSAMP(KS)
          do 470 ispot=1,nvgrid
c*** re: delete a+
          vspot=float(ispot)*vstep
             rtemp1=0.0
             do jspot=1,nvgrid
c*** re: delete a+
                vspotj=float(jspot)*vstep
                  if((abs(vspotj-vspot).le.hband))then
                  rtemp1=rtemp1+Epanker(vspotj,vspot,hband,censor(ks,i))
     $                   *G(ks,i,jspot)*LAMBDAIPW(KS,I,JSPOT)*vstep
                  endif
            enddo
          CKLAMBDAIPW(KS,I,ISPOT)=rtemp1
  470    continue
  480 continue
  490 continue

      do  ks=1,kk
        do  i=1,nsamp(ks)
          CLAMBDAUG(ks,i)=0.0
        enddo
      enddo
      CUMB1(0)=0.0


      do 600 ispot=1,nvgrid
c*** re: delete a+
         vspot=float(ispot)*vstep

       do 550 ks=1,kk
       do 550 i=1,nsamp(ks)
c        deltak(ks,i)=uniker(mark(ks,i),vspot,hband,censor(ks,i))
c        deltak(ks,i)=normker(mark(ks,i),vspot,hband,censor(ks,i))
         deltak(ks,i)=Epanker(mark(ks,i),vspot,hband,censor(ks,i))


       if((time(ks,i).le.tau).and.
     $    (censor(ks,i).gt.0.5).and.
     $    (CLAMBDAIPW(KS,I).gt. 0.00000001))then
            DRHOipw(KS,I)=CKLAMBDAIPW(KS,I,ISPOT)/CLAMBDAIPW(KS,I)
       else
            DRHOipw(ks,i)=0.0
       endif
c       print*,'i, DRHOipw(ks,i)= ', i, DRHOipw(ks,i)
 550   continue


c      initial value
       do j=1,ncov
         betaaug0(j)=betaipw(j,ispot)
       enddo

        call estpaug(tau,tstep,ntgrid,TBAND,kk,nsamp,ncov,time,covart,
     $ censor,deltak,wght,DRHOipw,betaaug0,LAMBDA0,LAMBDAk0,F,varaug)

       do j=1,ncov
       betaaug(j,ispot)=betaaug0(j)
       seaug(j,ispot)=sqrt(varaug(j,j))
       enddo


       CUMB1(iskip-1)=0.0
       if (ispot.ge.iskip)then
c      calculate cumulative beta_1(v):
       CUMB1(ispot)=CUMB1(ispot-1)+betaaug(1,ispot)*vstep
       endif


c      Inverse matrix of information matrix:
        do j=1,ncov
          betaofv(j,ispot)=betaaug(j,ispot)
          do k=1,ncov
           SigmaInv(j,k,ispot)=F(j,k)
          enddo
        enddo

c      calculate the baseline hazard functions:
       do ks=1,kk
         do itgrid=1,ntgrid
           Lamktv0(ks,itgrid,ispot)=LAMBDAk0(ks,itgrid)
         enddo
       enddo

C      CALCULATE CLAMBDA(KS,I)= $\int_0^1 \lambda_k(t,u|z) h_k(a|t,u,z) du$ AT $W_{ki}=(T_{ki},Z_{ki})$:

       DO 580 KS=1,KK
       DO 560 I=1,NSAMP(KS)
         if ((time(ks,i).le.tau).and.(censor(ks,i).gt.0.5)) then
         BZaug=0.0
         DO J=1,NCOV
            BZaug=BZaug+BETAaug(J,ispot)*COVART(KS,J,I,1)
         ENDDO
          LAMBDAUG(KS,I,ISPOT)=LAMBDA0(KS,I)*EXP(BZaug)
          CLAMBDAUG(KS,I)=CLAMBDAUG(KS,I)+G(ks,i,ispot)
     &                   *LAMBDA0(KS,I)*EXP(BZaug)*VSTEP
         
         endif
  560 CONTINUE
  580 CONTINUE

c      95% confidence interval for beta1(v):
c       beta1lw(ispot)=betaaug(1,ispot)-1.96*sqrt(varaug(1,1))
c       beta1up(ispot)=betaaug(1,ispot)+1.96*sqrt(varaug(1,1))

c      write out the baseline estimates at each vspot:
c      do ks=1,kk
c         do i=1,nsamp(k)
c            write(33,*) vspot, ks,i, time(ks,i),lambdak0(ks,i)
c          enddo
c       enddo

c    estimate of VE(v):
        veest(ispot)=1.-exp(betaaug(1,ispot))
c    One estimate of s.e. of \hat VE(v):
        vese(ispot)=seaug(1,ispot)*exp(betaaug(1,ispot))

 600  continue

      write(66,*)' v, ', '  ESTcom,  SEcom, ','  ESTipw,  SEipw, ',
     & '  ESTaug,  SEaug, ', '  ESTVEaug','  SEVEaug, '


      do 2300 ispot=1,nvgrid
c*** re: delete a+
      vspot=float(ispot)*vstep
       write(66,551) (vspot,betacom(j,ispot),secom(j,ispot),
     & betaipw(j,ispot), 
     & seipw(j,ispot),betaaug(j,ispot),seaug(j,ispot),j=1,ncov),
     & veest(ispot), vese(ispot)
 551  format(F8.4,8F9.4)
2300  continue
      close(66)


c  ***********************************************************************
c           calculate the quantities needed for GDIST2N
c  *************************************************************************
 
      DO 700 ispot=iskip,nvgrid
c*** re: delete a+
c         va=a0+vstep*(float(ispot)-1.0)
c         vb=a0+vstep*float(ispot)
c         vspot=a0+float(ispot)*vstep
       va=vstep*(float(ispot)-1.0)
       vb=vstep*float(ispot)
       vspot=float(ispot)*vstep

 
       do j=1,Ncov
       do k=1,Ncov
          sigtemp(j,k)=0.0
       enddo
       enddo

       do 630 mspot=iskip,nvgrid
c*** re: delete a+
c           vmspot=a0+ float(mspot)*vstep
           vmspot=float(mspot)*vstep
           do j=1,Ncov
           do k=1,Ncov
              sigtemp(j,k)=sigtemp(j,k)+sigmaInv(j,k,mspot)
     $         *Epanker(vspot,vmspot,hband,1.0)*vstep
              AsigInv(j,k,ispot,mspot)=sigtemp(j,k)
           enddo
           enddo
 630   continue
 

 
       do 650 ks=1,kk
       do 650 i=1,Nsamp(ks)
       if((time(ks,i).le.tau).and.
     $    (censor(ks,i).gt.0.5).and.
     $    (CLAMBDAUG(KS,I).gt. 0.00000001)) then
            DRHOaug(KS,I)=G(ks,i,ispot)*LAMBDAUG(KS,I,ISPOT)
     $                    /CLAMBDAUG(KS,I)
         else
            DRHOaug(ks,i)=0.0
         endif
 650    continue

       do 680 ks=1,kk
       do 680 i=1,Nsamp(ks)
         if ((time(ks,i).le.tau).and.(censor(ks,i).gt.0.5)) then
             temp1=(1.0-wght(ks,i))*drhoaug(ks,i)*vstep
         else
             temp1=0.
         endif

         if ((time(ks,i).le.tau).and.(mark(ks,i).gt.va).and.
     &      (mark(ks,i).le.vb).and.(censor(ks,i).gt.0.5)) then
             temp2=wght(ks,I)
         else
             temp2=0.
         endif
        tempaug(ks,i,ispot)=temp1+temp2
 680    continue
 700    continue

 
c      DO 900 ispot=1,nvgrid
      DO 900 ispot=iskip,nvgrid
      do 890 ks=1,kk

c    for time independent covariates
      DO 830 I=1,Nsamp(ks)
c      do 830 k=1,nsamp(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 820 J=1,Ncov
c            BZt(I,k)=BZt(I,k)+BETAofv(J,ispot)*covart(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETAofv(J,ispot)*covart(ks,J,I,1)
 820    CONTINUE
 830  CONTINUE

      DO 880 I=1,Nsamp(ks)
         S0(I)=0.0
         DO 845 J=1,Ncov
            S1(J,I)=0.0
 845    CONTINUE
         DO 870 L=1,Nsamp(ks)
          IF (time(ks,L).GE.time(ks,I)) THEN
c           S0(I)=S0(I)+EXP(BZt(L,i))
           S0(I)=S0(I)+EXP(BZt(L,1))
            DO 860 J=1,Ncov
c              S1(J,I)=S1(J,I)+EXP(BZt(L,i))*covart(ks,J,L,i)
              S1(J,I)=S1(J,I)+EXP(BZt(L,1))*covart(ks,J,L,1)
 860       CONTINUE
          ENDIF
 870    CONTINUE

      S0N(ks,i,ispot)=S0(I)
      do j=1,Ncov
      S1N(j,ks,i,ispot)=S1(J,I)
      enddo

 880  CONTINUE
 890  continue
 900  continue

c  *************************************************************************
c         finish  calculating the quantities needed for GDIST2N
c  *************************************************************************
 



c   ***********************************************************************
c    Simulate distribution of \sqrt n(\hat B(v)-B(v))  based on aipw
c   ***********************************************************************

c
      do ispot=1,nvgrid
         CUMB1x(ispot)=0.0
         CUMB1se(ispot)=0.0
      enddo

      do 1000 iboot=1,nboot

       do ks=1,kk
        do i=1,nsamp(ks)
         zdev(ks,i)=gennor(0.,1.)
        enddo
       enddo

c     calculate the Gaussian multiplier process CUMBDIST for each iboot

       CALL GDIST2N(nvgrid,iskip,zdev,KK,Nsamp,Ncov,time,covart,
     & betaofv,SigmaInv,S0N,S1N,tempaug,AsigInv,CUMBDIST)

c      do ispot=1,nvgrid
      do ispot=iskip,nvgrid
c*** re: delete a+
c         vspot=a0+float(ispot)*vstep
         vspot=float(ispot)*vstep
         CUMB1x(ispot)=CUMB1x(ispot)+CUMBDIST(1,ispot)
         CUMB1se(ispot)=CUMB1se(ispot)+CUMBDIST(1,ispot)**2.0
      enddo

c      print*, 'CUMBDIST= ', (CUMBDIST(1,ispot),ispot=1,50)
c      print*, 'Lamktv0= ', (Lamktv0(1,1,ispot), ispot=1,50)
c      print*, '        '

      do ispot=1,nvgrid
        BootDist(iboot,ispot)=CUMBDIST(1,ispot)
      enddo

1000  continue


c      do ispot=1,nvgrid
      do ispot=iskip,nvgrid

c     bootstrap standard error of the IPWA estimator $\hat B_1(v)-B_1(v)$:
         CUMB1x(ispot)=CUMB1x(ispot)/float(nboot)
         CUMB1se(ispot)=sqrt((CUMB1se(ispot)-(CUMB1x(ispot))**2.0
     &                       *float(nboot))/float(nboot))

      enddo


cccccccccccccccccccccc  Change Starts  ccccccccccccccccccccccccc
cc**************************************************************
c   This data application version is different from the simulation
c   version; it is more flexible; it can construct test statistics
c   on [a1,b1] or [a2,b1].
cc**************************************************************

cc     calculate the test statistics for H_{10}:VE(v)=0 for v over [a1,b1], b1=1

      iskipa1=a1/vstep
      nvgrid1=b1/vstep

cc     calculate the test statistics for H_{20}:VE(v)=VE for v over [a2,b1], a2>a1    
      iskipa2=a2/vstep


      cBproc1(iskipa1)=CUMB1(iskipa1)-CUMB1(iskipa1) 
 
      cBproc2(iskipa2)=(CUMB1(iskipa2)-CUMB1(iskipa1))/(a2-a1)
     & -(CUMB1(nvgrid1)-CUMB1(iskipa1))/(b1-a1)

      TSUP1=abs(cBproc1(iskipa1))
      TSUP1m=cBproc1(iskipa1)
      TSUP2=abs(cBproc2(iskipa2))
      TSUP2m=cBproc2(iskipa2)

      Tint1=0.
      Tint1m=0.
      Tint2=0.
      Tint2m=0.

      do 1130 ispot=iskipa1+1,nvgrid1
c      vspot=a1+float(ispot)*vstep
      vspot=float(ispot)*vstep


c      cBproc1(ispot)=CUMB1(ispot)/CUMB1se(ispot)
      cBproc1(ispot)=CUMB1(ispot)-CUMB1(iskipa1) 

      cBproc2(ispot)=(CUMB1(ispot)-CUMB1(iskipa1))/(vspot-a1)
     & -(CUMB1(nvgrid1)-CUMB1(iskipa1))/(b1-a1)


c**************************************************
c    two-sided tests for testing $H_1$:
      if(abs(cBproc1(ispot)).gt.TSUP1)then
      TSUP1=abs(cBproc1(ispot))
      endif

      Tint1=Tint1+cBproc1(ispot)**2.0
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)

c    one-sided tests for testing $H_1$:
      if(cBproc1(ispot).lt.TSUP1m)then
      TSUP1m=cBproc1(ispot)
      endif

      Tint1m=Tint1m+cBproc1(ispot)
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)


c**************************************************
      IF(ispot.ge.iskipa2)THEN

c    two-sided tests for testing $H_2$:
      if(abs(cBproc2(ispot)).gt.TSUP2)then
      TSUP2=abs(cBproc2(ispot))
      endif

      Tint2=Tint2+cBproc2(ispot)**2.0
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)

c    one-sided tests for testing $H_2$:
      if(cBproc2(ispot).lt.TSUP2m)then
      TSUP2m=cBproc2(ispot)
      endif

      Tint2m=Tint2m+cBproc2(ispot)
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)

      ENDIF

1130  continue

c      print*, '                        '
c      print*,'TSUP1, TSUP1m = ', TSUP1, TSUP1m
c      print*,'TSUP2, TSUP2m = ', TSUP2, TSUP2m
c      print*, '                        '


cc*****************************************************************
cc     Find the p-values of the test statistics.
cc*****************************************************************

c     the initial values for p-values

      TSUP1pv=0.0
      TSUP1mpv=0.0
      TSUP2pv=0.0
      TSUP2mpv=0.0

      Tint1pv=0.0
      Tint1mpv=0.0
      Tint2pv=0.0
      Tint2mpv=0.0


      do 1400 iboot=1,nboot

      cBproc1x(iskipa1)=BootDist(iboot,iskipa1)
     & -BootDist(iboot,iskipa1)

      temp2nd= (BootDist(iboot,nvgrid1)
     & -BootDist(iboot,iskipa1))/(b1-a1)

      cBproc2x(iskipa2)=(BootDist(iboot,iskipa2)
     & -BootDist(iboot,iskipa1))/(a2-a1)
     & -temp2nd

      TSUP1x=abs(cBproc1x(iskipa1))
      TSUP1mx=cBproc1x(iskipa1)
      TSUP2x=abs(cBproc2x(iskipa2))
      TSUP2mx=cBproc2x(iskipa2)

      Tint1x=0.
      Tint1mx=0.
      Tint2x=0.
      Tint2mx=0.

      do 1230 ispot=iskipa1+1,nvgrid1
c            vspot=a1+float(ispot)*vstep
      vspot=float(ispot)*vstep

      cBproc1x(ispot)=BootDist(iboot,ispot)
     & -BootDist(iboot,iskipa1)

      cBproc2x(ispot)=(BootDist(iboot,ispot)
     & -BootDist(iboot,iskipa1))/(vspot-a1)
     & -temp2nd


c**************************************************
ccc  for plotting the Gaussian multiplier realizations; the actual processes need to multiply by sqrt(n):
      if((isim.eq.1).and.(iboot.le.20)) then
        cBproc1s(ispot,iboot)=sqrt(rnsamp)*cBproc1x(ispot)
        cBproc2s(ispot,iboot)=sqrt(rnsamp)*cBproc2x(ispot)
      endif


c**************************************************
c    two-sided tests for testing $H_1$:
      if(abs(cBproc1x(ispot)).gt.TSUP1x)then
      TSUP1x=abs(cBproc1x(ispot))
      endif

      Tint1x=Tint1x+cBproc1x(ispot)**2.0
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)


c    one-sided tests for testing $H_1$:
      if(cBproc1x(ispot).lt.TSUP1mx)then
      TSUP1mx=cBproc1x(ispot)
      endif

      Tint1mx=Tint1mx+cBproc1x(ispot)
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)


c**************************************************
      IF(ispot.ge.iskipa2)THEN

c    two-sided tests for testing $H_2$:
      if(abs(cBproc2x(ispot)).gt.TSUP2x)then
      TSUP2x=abs(cBproc2x(ispot))
      endif

      Tint2x=Tint2x+cBproc2x(ispot)**2.0
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)

c    one-sided tests for testing $H_2$:
      if(cBproc2x(ispot).lt.TSUP2mx)then
      TSUP2mx=cBproc2x(ispot)
      endif

      Tint2mx=Tint2mx+cBproc2x(ispot)
     &           *(CUMB1se(ispot)**2.-CUMB1se(ispot-1)**2.)

      ENDIF

1230  continue
cccccccccccccccccccccc  Change Ends  ccccccccccccccccccccccccc

c**************************************************
c     calculate bootstrap p-values for H10:

      if(TSUP1x.gt.TSUP1)then
      TSUP1pv=TSUP1pv+1.0/float(nboot)
      endif

      if(TSUP1mx.lt.TSUP1m)then
      TSUP1mpv=TSUP1mpv+1.0/float(nboot)
      endif

      if(Tint1x.gt.Tint1)then
      Tint1pv=Tint1pv+1.0/float(nboot)
      endif

      if(Tint1mx.lt.Tint1m)then
      Tint1mpv=Tint1mpv+1.0/float(nboot)
      endif

c     calculate bootstrap p-values for H20:

      if(TSUP2x.gt.TSUP2)then
      TSUP2pv=TSUP2pv+1.0/float(nboot)
      endif

      if(TSUP2mx.lt.TSUP2m)then
      TSUP2mpv=TSUP2mpv+1.0/float(nboot)
      endif

      if(Tint2x.gt.Tint2)then
      Tint2pv=Tint2pv+1.0/float(nboot)
      endif

      if(Tint2mx.lt.Tint2m)then
      Tint2mpv=Tint2mpv+1.0/float(nboot)
      endif

c      write(44,*) isim, iboot, ' TSUP1x, TSUP1mx = ', TSUP1x, TSUP1mx
c      write(44,*) isim, iboot, ' TSUP2x, TSUP2mx = ', TSUP2x, TSUP2mx

1400  continue

c      print*, '                        '
c      print*,'p-values of TSUP1, TSUP1m = ', TSUP1pv, TSUP1mpv
c      print*,'p-values of TSUP2, TSUP2m = ', TSUP2pv, TSUP2mpv
c      print*, '                        '


cc     the actual test statistics need to multiply by sqrt(n):

       TSUP1=sqrt(rnsamp)*TSUP1
       TSUP1m =sqrt(rnsamp)*TSUP1m
       Tint1 =sqrt(rnsamp)*Tint1
       Tint1m =sqrt(rnsamp)*Tint1m

       TSUP2 =sqrt(rnsamp)*TSUP2
       TSUP2m =sqrt(rnsamp)*TSUP2m
       Tint2 =sqrt(rnsamp)*Tint2
       Tint2m =sqrt(rnsamp)*Tint2m


      write(44,*) 'Test Statistics and p-values:'
      write(44,*) '                     '
      write(44,1404) isim,  ' TSUP1, TSUP1m, Tint1, Tint1m = ',
     &            TSUP1, TSUP1m, Tint1, Tint1m
      write(44,1406)'      p-values of TSUP1, TSUP1m, Tint1, Tint1m = ',
     &            TSUP1pv,TSUP1mpv,Tint1pv,Tint1mpv
      write(44,*) '                     '
      write(44,1406) '    TSUP2, TSUP2m, Tint2, Tint2m = ',
     &            TSUP2, TSUP2m,Tint2,Tint2m
      write(44,1406)'      p-values of TSUP2, TSUP2m, Tint2, Tint2m = ',
     &            TSUP2pv,TSUP2mpv,Tint2pv,Tint2mpv

 1404  format(I12, A35, 4F12.6)
 1406  format(A48, 4F12.6)



cc     for plotting the test processes and the Gaussian multiplier processes;
cc     the actual test processes need to multiply by sqrt(n):
      if(isim.eq.1) then
        do ispot=iskipa1+1,nvgrid
         vspot= float(ispot)*vstep
         cBproc1(ispot)=sqrt(rnsamp)*cBproc1(ispot)
         write(22,1408) vspot,cBproc1(ispot),(cBproc1s(ispot,k),k=1,20)
       if(ispot.ge.iskipa2)then
         cBproc2(ispot)=sqrt(rnsamp)*cBproc2(ispot)
         write(25,1408) vspot,cBproc2(ispot),(cBproc2s(ispot,k),k=1,20)
       endif
        enddo
       endif
 1408  format(F8.4, 21F10.4)
       close(22)
       close(25)

 2000 continue

      Rmiss=Rsum/sumdelta

      write(44,*)' number of uncensored:  ', sumdelta
      write(44,*) 'percent of observed among uncensored: ',Rmiss

      write(44,*)'                '
      write(44,*)'Censoring rate = ', 100.*(1.-sumdelta/float(nsampa))
      write(44,*)'                '

      write(44,*)'Number of infns before tau=3.5 for Vaccine: ',rinfect1
      write(44,*)'                '
      write(44,*)'Number of infns before tau=3.5 for Placebo: ',rinfect0


      write(44,*)'                '
      write(44,*)'                '
      write(44,*)' ************************************************** '
      write(44,*)'                '

      close(44)

      END


CC
C     *****************************************************************
C     *                                                               *
C     *            SUBROUTINE  matrix A times B gives C               *
C     *    NP, MP, LP are the declared dimensions and N, M, L are     *
C     *    the  actual dimensions                                     *
C     *****************************************************************
C
C
      SUBROUTINE ATIMEB(A,B,C,N,NP,M,MP,L,LP)
      DIMENSION A(NP,MP),B(MP,LP), C(NP,LP)

      do 20 i=1,n
      do 20 j=1,L
      c(i,j)=0.0
      do 30 k=1,m
      c(i,j)=c(i,j)+a(i,k)*b(k,j)
 30   continue
 20   continue
      return
      end


C
C     *****************************************************************
C     *                                                               *
C     *                    ESTPVRY       SUBROUTINE                   *
C     *                                                               *
C     * estimate the time-varying coefficient in the cox model        *
C     *****************************************************************
C
C
c      SUBROUTINE estpvry(tau,KK,N,NP,X,ZT,CENSOR,DELTA,S0,S1,S2,BETA,GS,
c     &       U,U2,F,var)
      SUBROUTINE estpvry(tau,KK,N,NP,X,ZT,CENSOR,DELTA,BETA,var)
      parameter(mxn=20000,mxkk=1)
C
C      IMPLICIT REAL*8(A-H,O-Z)
      REAL X(mxkk,mxn),CENSOR(mxkk,mxn),DELTA(mxkk,mxn),
     &  zt(mxkk,np,mxn,1),bzt(mxn,1),
     &  S0(mxn),S1(NP,mxn),S2(NP,NP),U(NP),U2(NP),
     &  F(NP,NP),F2(NP,NP),var(NP,NP), BETA(NP), FF2(NP,NP)

      Integer kk,ks,N(mxkk)

c      KL=10
      KL=6
      do 900 KITER=1,KL

      DO 80 J=1,NP
         U(J)=0.0
            DO 60 K=1,NP
               F(J,K)=0.0
               F2(J,K)=0.0
   60       CONTINUE
   80 CONTINUE


c*******************************************************************
      do 405 ks=1,kk

cctcc
      DO 205 I=1,N(ks)
c      do 205 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 190 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETA(J)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETA(J)*Zt(ks,J,I,1)
  190    CONTINUE
  205  CONTINUE
c*******************************************************************

      DO 400 I=1,N(ks)
         if (X(ks,i).le.tau) then

         S0(I)=0.0
         DO 220 J=1,NP
            S1(J,I)=0.0
            DO 210 K=1,NP
               S2(J,K)=0.0
  210       CONTINUE
  220    CONTINUE

cctcc
         DO 300 L=1,N(ks)
          IF (X(ks,L).GE.X(ks,I)) THEN
c           S0(I)=S0(I)+EXP(BZt(L,i))
           S0(I)=S0(I)+EXP(BZt(L,1))
            DO 280 J=1,NP
c              S1(J,I)=S1(J,I)+EXP(BZt(L,i))*Zt(ks,J,L,i)
              S1(J,I)=S1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)
                DO 260 K=1,NP
c                S2(J,K)=S2(J,K)+EXP(BZt(L,i))*Zt(ks,J,L,i)*Zt(ks,K,L,i)
                S2(J,K)=S2(J,K)+EXP(BZt(L,1))*Zt(ks,J,L,1)*Zt(ks,K,L,1)
  260           CONTINUE
  280       CONTINUE
          ENDIF
  300    CONTINUE

c???
          if (S0(I).gt.0.00000001)then
         DO 380 J=1,NP
cctcc
c            U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,I)-S1(J,I)/S0(I))
            U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,1)-S1(J,I)/S0(I))
            U2(J)=U(J)
            DO 360 K=1,NP
               F(J,K)=F(J,K)+DELTA(ks,I)*(S2(J,K)/S0(I)
     &                -S1(J,I)*S1(K,I)/S0(I)**2)
               F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(S2(J,K)/S0(I)
     &                -S1(J,I)*S1(K,I)/S0(I)**2)
  360       CONTINUE
  380    CONTINUE
C
      endif
      endif
  400 CONTINUE
  405 continue

      CALL GAUSSJ(F,NP,NP,U,1,1)

      DO 800 J=1,NP
         BETA(J)=BETA(J)+U(J)
         DO 700 K=1,NP
  700    CONTINUE
  800 CONTINUE

c     the output F(j,k) is the inverse matrix of the input F which is minus the
c     matrix of second order partial derivatives of the partial likelihood C(\beta)
c     U2 here is the score vector
c     GS is like the score test statistic

  900 CONTINUE
C     the variance of \hat\beta(v) is var in the following

      call ATIMEB(F,F2,FF2,NP,NP,NP,NP,NP,NP)
      call ATIMEB(FF2,F,var,NP,NP,NP,NP,NP,NP)


C     RETURN
      END




C
C     *****************************************************************
C     *                                                               *
C     *                    ESTPCOM       SUBROUTINE                   *
C     *                                                               *
C     * Complete data estimate the varying coefficient in the mark PH model     *
C     *****************************************************************
C
C
      SUBROUTINE estpcom(tau,KK,N,NP,X,ZT,CENSOR,DELTA,WGHT,BETA,F,var)
      parameter(mxn=20000,mxkk=1)
C
C      IMPLICIT REAL*8(A-H,O-Z)
      REAL X(mxkk,mxn),CENSOR(mxkk,mxn),DELTA(mxkk,mxn),
     &  zt(mxkk,np,mxn,1),bzt(mxn,1),wght(mxkk,mxn),
     &  S0(mxn),S1(NP,mxn),S2(NP,NP),U(NP),U2(NP),
     &  F(NP,NP),F2(NP,NP),var(NP,NP), BETA(NP), FF2(NP,NP)

      Integer kk,ks,N(mxkk)

c      KL=10
      KL=6
      do 900 KITER=1,KL

      DO 80 J=1,NP
         U(J)=0.0
            DO 60 K=1,NP
               F(J,K)=0.0
               F2(J,K)=0.0
   60       CONTINUE
   80 CONTINUE


c*******************************************************************
      do 600 ks=1,kk

cctcc
      DO 205 I=1,N(ks)
c      do 205 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 190 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETA(J)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETA(J)*Zt(ks,J,I,1)
  190    CONTINUE
  205  CONTINUE
c*******************************************************************
c     S0 can be zero !!!

      DO 400 I=1,N(ks)
         if (X(ks,i).le.tau) then

         S0(I)=0.0
         DO 220 J=1,NP
            S1(J,I)=0.0
            DO 210 K=1,NP
               S2(J,K)=0.0
  210       CONTINUE
  220    CONTINUE

cctcc
         DO 300 L=1,N(ks)
          IF (X(ks,L).GE.X(ks,I)) THEN
c           S0(I)=S0(I)+EXP(BZt(L,i))*wght(ks,L)
           S0(I)=S0(I)+EXP(BZt(L,1))*wght(ks,L)
            DO 280 J=1,NP
c              S1(J,I)=S1(J,I)+EXP(BZt(L,i))*Zt(ks,J,L,i)*wght(ks,L)
              S1(J,I)=S1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)*wght(ks,L)
                DO 260 K=1,NP
c                S2(J,K)=S2(J,K)+EXP(BZt(L,i))*Zt(ks,J,L,i)*Zt(ks,K,L,i)
c     &                   *wght(ks,L)
                S2(J,K)=S2(J,K)+EXP(BZt(L,1))*Zt(ks,J,L,1)*Zt(ks,K,L,1)
     &                   *wght(ks,L)

  260           CONTINUE
  280       CONTINUE
          ENDIF
  300    CONTINUE

         DO 380 J=1,NP
c???
         if (S0(I).gt.0.00000001)then
cctcc
c          U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,I)-S1(J,I)/S0(I))*wght(ks,I)
          U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,1)-S1(J,I)/S0(I))*wght(ks,I)
            U2(J)=U(J)
            DO 360 K=1,NP
               F(J,K)=F(J,K)+DELTA(ks,I)*(S2(J,K)/S0(I)
     &                -S1(J,I)*S1(K,I)/S0(I)**2)*wght(ks,I)
cctcc
c          F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(Zt(ks,J,I,I)-S1(J,I)/S0(I))
c     &                *(Zt(ks,K,I,I)-S1(K,I)/S0(I))*wght(ks,I)**2
          F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(Zt(ks,J,I,1)-S1(J,I)/S0(I))
     &                *(Zt(ks,K,I,1)-S1(K,I)/S0(I))*wght(ks,I)**2
c               F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(S2(J,K)/S0(I)
c     &                -S1(J,I)*S1(K,I)/S0(I)**2)
  360       CONTINUE
         endif
  380    CONTINUE
      endif
  400 CONTINUE
  600 continue

      CALL GAUSSJ(F,NP,NP,U,1,1)
      DO 800 J=1,NP
         BETA(J)=BETA(J)+U(J)
  800 CONTINUE
  900 CONTINUE

C     the variance of \hat\beta(v) is var in the following
      call ATIMEB(F,F2,FF2,NP,NP,NP,NP,NP,NP)
      call ATIMEB(FF2,F,var,NP,NP,NP,NP,NP,NP)


C     RETURN
      END





C
C     *****************************************************************
C     *                                                               *
C     *                    ESTPIPW       SUBROUTINE                   *
C     *                                                               *
C     * IPW estimate the varying coefficient in the mark PH model     *
C     *****************************************************************
C
C
      SUBROUTINE estpipw(tau,KK,N,TBAND,NP,X,ZT,CENSOR,DELTA,
     &                     WGHT,BETA,LAMBDA0,F,var)
      parameter(mxn=20000,mxkk=1)
C
C      IMPLICIT REAL*8(A-H,O-Z)
      REAL X(mxkk,mxn),CENSOR(mxkk,mxn),DELTA(mxkk,mxn),
     &  zt(mxkk,np,mxn,1),bzt(mxn,1),wght(mxkk,mxn),
     &  S0(mxn),S1(NP,mxn),S2(NP,NP),U(NP),U2(NP),
     &  F(NP,NP),F2(NP,NP),var(NP,NP), BETA(NP), FF2(NP,NP),
     & LAMBDA0(MXKK,MXN)

      Integer kk,ks,N(mxkk)

c      KL=10
      KL=6
      do 900 KITER=1,KL

      DO 80 J=1,NP
         U(J)=0.0
            DO 60 K=1,NP
               F(J,K)=0.0
               F2(J,K)=0.0
   60       CONTINUE
   80 CONTINUE


c*******************************************************************
      do 600 ks=1,kk

cctcc
      DO 205 I=1,N(ks)
c      do 205 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 190 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETA(J)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETA(J)*Zt(ks,J,I,1)
  190    CONTINUE
  205  CONTINUE
c*******************************************************************
c     S0 can be zero !!!

      DO 400 I=1,N(ks)
         if (X(ks,i).le.tau) then

         S0(I)=0.0
         DO 220 J=1,NP
            S1(J,I)=0.0
            DO 210 K=1,NP
               S2(J,K)=0.0
  210       CONTINUE
  220    CONTINUE

cctcc
         DO 300 L=1,N(ks)
          IF (X(ks,L).GE.X(ks,I)) THEN
c           S0(I)=S0(I)+EXP(BZt(L,i))*wght(ks,L)
           S0(I)=S0(I)+EXP(BZt(L,1))*wght(ks,L)
            DO 280 J=1,NP
c              S1(J,I)=S1(J,I)+EXP(BZt(L,i))*Zt(ks,J,L,i)*wght(ks,L)
              S1(J,I)=S1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)*wght(ks,L)
                DO 260 K=1,NP
c                S2(J,K)=S2(J,K)+EXP(BZt(L,i))*Zt(ks,J,L,i)*Zt(ks,K,L,i)
c     &                   *wght(ks,L)
                S2(J,K)=S2(J,K)+EXP(BZt(L,1))*Zt(ks,J,L,1)*Zt(ks,K,L,1)
     &                   *wght(ks,L)

  260           CONTINUE
  280       CONTINUE
          ENDIF
  300    CONTINUE

c????
         if (S0(I).gt.0.00000001)then
         DO 380 J=1,NP
cctcc
c          U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,I)-S1(J,I)/S0(I))*wght(ks,I)
          U(J)=U(J)+DELTA(ks,I)*(Zt(ks,J,I,1)-S1(J,I)/S0(I))*wght(ks,I)
            U2(J)=U(J)
            DO 360 K=1,NP
               F(J,K)=F(J,K)+DELTA(ks,I)*(S2(J,K)/S0(I)
     &                -S1(J,I)*S1(K,I)/S0(I)**2)*wght(ks,I)
cctcc
c          F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(Zt(ks,J,I,I)-S1(J,I)/S0(I))
c     &                *(Zt(ks,K,I,I)-S1(K,I)/S0(I))*wght(ks,I)**2
          F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(Zt(ks,J,I,1)-S1(J,I)/S0(I))
     &                *(Zt(ks,K,I,1)-S1(K,I)/S0(I))*wght(ks,I)**2
c               F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(S2(J,K)/S0(I)
c     &                -S1(J,I)*S1(K,I)/S0(I)**2)
  360       CONTINUE
  380    CONTINUE
         endif
      endif
  400 CONTINUE

c      print*, 'S0 =', (S0(i),i=1,500)
c      print*, 'S1 =', (S1(1,i),i=1,500)
c      print*,'F for beta(v)= ', F

C     CALCULATE THE BASELINE HAZARD FUNCTION AT X(KS,I) AND VSPOT:

      IF(KITER.EQ.KL) THEN
      DO 550 I=1,N(KS)
      TEMPB=0.0
        DO 500 II=1,N(KS)
c???
         if ((X(ks,ii).le.tau).and.(S0(II).gt.0.00000001))then
           TEMPB=TEMPB+EPANKER(X(KS,II),X(KS,I),TBAND,CENSOR(KS,II))
     $            *DELTA(ks,II)*WGHT(KS,II)/S0(II)
         endif
  500   CONTINUE
      LAMBDA0(KS,I)=TEMPB
  550 CONTINUE
      ENDIF
  600 continue

      CALL GAUSSJ(F,NP,NP,U,1,1)
      DO 800 J=1,NP
         BETA(J)=BETA(J)+U(J)
  800 CONTINUE
c      print*,'U for beta(v), beta(v)= ', U(1), beta(1)

  900 CONTINUE

C     the variance of \hat\beta(v) is var in the following
      call ATIMEB(F,F2,FF2,NP,NP,NP,NP,NP,NP)
      call ATIMEB(FF2,F,var,NP,NP,NP,NP,NP,NP)

C     RETURN
      END





C
C     *****************************************************************
C     *                                                               *
C     *                    ESTPAUG       SUBROUTINE                   *
C     *                                                               *
C     *AIPW estimate the varying coefficient in the mark PH model     *
C     *****************************************************************
C
      SUBROUTINE estpaug(tau,tstep,ntgrid,TBAND,KK,N,NP,X,ZT,CENSOR,
     &                  DELTA,WGHT,DRHOipw,BETA,LAMBDA0,LAMBDAk0,F,var)
      parameter(mxn=20000,mxkk=1,mxtgrid=100)
C
C      IMPLICIT REAL*8(A-H,O-Z)
      REAL X(mxkk,mxn),CENSOR(mxkk,mxn),DELTA(mxkk,mxn),
     &  zt(mxkk,np,mxn,1),bzt(mxn,1),wght(mxkk,mxn),
     &  S0(mxkk,mxn),S1(NP,mxn),S2(NP,NP),U(NP),U2(NP),
     &  F(NP,NP),F2(NP,NP),var(NP,NP), BETA(NP), FF2(NP,NP),
     &  LAMBDA0(mxkk,mxn), LAMBDAk0(MXKK,mxtgrid),DRHOipw(MXKK,MXN)

      Integer kk,ks,N(mxkk)

c      print*, 'DRHOipw= ', DRHOipw

c      KL=10
      KL=6
      do 900 KITER=1,KL

      DO 80 J=1,NP
         U(J)=0.0
            DO 60 K=1,NP
               F(J,K)=0.0
               F2(J,K)=0.0
   60       CONTINUE
   80 CONTINUE


c*******************************************************************
      do 600 ks=1,kk

cctcc
      DO 205 I=1,N(ks)
c      do 205 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 190 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETA(J)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETA(J)*Zt(ks,J,I,1)
  190    CONTINUE
  205  CONTINUE
c*******************************************************************

      DO 400 I=1,N(ks)
         if (X(ks,i).le.tau) then

         S0(ks,I)=0.0
         DO 220 J=1,NP
            S1(J,I)=0.0
            DO 210 K=1,NP
               S2(J,K)=0.0
  210       CONTINUE
  220    CONTINUE

cctcc
         DO 300 L=1,N(ks)
          IF (X(ks,L).GE.X(ks,I)) THEN
c           S0(ks,I)=S0(ks,I)+EXP(BZt(L,i))
           S0(ks,I)=S0(ks,I)+EXP(BZt(L,1))
            DO 280 J=1,NP
c              S1(J,I)=S1(J,I)+EXP(BZt(L,i))*Zt(ks,J,L,i)
              S1(J,I)=S1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)
                DO 260 K=1,NP
c                S2(J,K)=S2(J,K)+EXP(BZt(L,i))*Zt(ks,J,L,i)*Zt(ks,K,L,i)
                S2(J,K)=S2(J,K)+EXP(BZt(L,1))*Zt(ks,J,L,1)*Zt(ks,K,L,1)
  260           CONTINUE
  280       CONTINUE
          ENDIF
  300    CONTINUE

c  The score function for AIPW estimator:
c???
         if (S0(ks,I).gt.0.00000001)then
         DO 380 J=1,NP
cctcc
c         U(J)=U(J)+(Zt(ks,J,I,I)-S1(J,I)/S0(ks,I))*(wght(ks,I)
c     &     *DELTA(ks,I)+(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i))
         U(J)=U(J)+(Zt(ks,J,I,1)-S1(J,I)/S0(ks,I))*(wght(ks,I)
     &     *DELTA(ks,I)+(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i))
         U2(J)=U(J)

            DO 360 K=1,NP
            F(J,K)=F(J,K)+(S2(J,K)/S0(ks,I)-S1(J,I)*S1(K,I)/S0(ks,I)**2)
     &                *(wght(ks,I)*DELTA(ks,I)
     &                   +(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i))

cctcc
c          F2(J,K)=F2(J,K)+(Zt(ks,J,I,I)-S1(J,I)/S0(ks,I))
c     &          *(Zt(ks,K,I,I)-S1(K,I)/S0(ks,I))*(wght(ks,I)*DELTA(ks,I)
c     &                 +(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i))**2


          F2(J,K)=F2(J,K)+(Zt(ks,J,I,1)-S1(J,I)/S0(ks,I))
     &          *(Zt(ks,K,I,1)-S1(K,I)/S0(ks,I))*(wght(ks,I)*DELTA(ks,I)
     &                 +(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i))**2

c          F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(Zt(ks,J,I,I)-S1(J,I)/S0(I))
c     &                *(Zt(ks,K,I,I)-S1(K,I)/S0(I))*wght(ks,I)**2
c               F2(J,K)=F2(J,K)+(DELTA(ks,I))**2*(S2(J,K)/S0(I)
c     &                -S1(J,I)*S1(K,I)/S0(I)**2)
  360       CONTINUE
  380    CONTINUE
         endif
C
      endif
  400 CONTINUE
C     CALCULATE THE BASELINE HAZARD FUNCTION AT X(KS,I) AND VSPOT:

      IF(KITER.EQ.KL) THEN
      DO 550 I=1,N(KS)
      TEMPB=0.0
        DO 500 II=1,N(KS)
         if (X(ks,ii).le.tau) then
         if (S0(ks,II).gt.0.00000001)then
           TEMPB=TEMPB+EPANKER(X(KS,II),X(KS,I),TBAND,CENSOR(KS,II))
     $            *(WGHT(KS,II)*DELTA(ks,II)
     $        +(1.0-wght(ks,ii))*censor(ks,ii)*drhoipw(ks,ii))/S0(ks,II)
         endif
         endif
  500   CONTINUE
      LAMBDA0(KS,I)=TEMPB
  550 CONTINUE
      ENDIF

  600 continue

c      print*, 'U= ',U, ' F= ', F

      CALL GAUSSJ(F,NP,NP,U,1,1)
c      print*, 'U= ',U, ' F= ', F

      DO 800 J=1,NP
         BETA(J)=BETA(J)+U(J)
  800 CONTINUE
  900 CONTINUE
C     the variance of \hat\beta(v) is var in the following

      call ATIMEB(F,F2,FF2,NP,NP,NP,NP,NP,NP)
      call ATIMEB(FF2,F,var,NP,NP,NP,NP,NP,NP)

C     CALCULATE THE BASELINE HAZARD FUNCTION AT X(KS,I) AND VSPOT:
c    change to the grid points of (t,v): !!!!!

      Do 1000 ks=1,kk
      DO 950 Itgrid=1,ntgrid
       tvalue=tstep*float(itgrid)
       TEMPB=0.0
        DO 920 I=1,N(KS)
         if (X(ks,i).le.tau) then
c???
         if (S0(ks,I).gt.0.00000001)then
           TEMPB=TEMPB+EPANKER(X(KS,I),tvalue,TBAND,CENSOR(KS,I))
     $            *(WGHT(KS,I)*DELTA(ks,I)/S0(ks,I)
     $        +(1.0-wght(ks,i))*censor(ks,i)*drhoipw(ks,i)/S0(ks,I))
         endif
         endif
  920   CONTINUE
      LAMBDAk0(KS,Itgrid)=TEMPB
  950 CONTINUE
 1000 CONTINUE


C     RETURN
      END




c****************************************************************************
c                       SUBROUTINE  GDIST2N
c     This is a modified version of GDIST2 where a different formula
c          is used when doing the change of order of integration
c                   involving the kernel function
c
c          The output of the subroutine GDIST2N is CUMBDIST,
c     which is  the Gaussian multiplier for $n^{1/2}(\hat B_{aug}(v)-B(v))$
c
c          THIS subroutine does not requires smoothing in t.
c                 the results are similar to GDIST1,
c           but GDIST1 may produce nan when TBAND is small
c****************************************************************************


c      SUBROUTINE GDIST2N(tau,a,vstep,nvgrid,iskip,zdev,KK,N,NP,X,ZT,mark,
c     &     xx1,xx2,CENSOR,WGHT,LAMBDAUG,CLAMBDAUG,betaofv,
c     &     SigmaInv,CUMBDIST)

      SUBROUTINE GDIST2N(nvgrid,iskip,zdev,KK,N,NP,X,ZT,
     & betaofv,SigmaInv,S0N,S1N,tempaug,AsigInv,CUMBDIST)

      parameter(mxn=20000,mxtgrid=100,mxv=200,mxkk=1)

      REAL X(mxkk,mxn),zt(mxkk,np,mxn,1), bzt(mxn,1),Sx0(mxn),
     & Sx1(NP,mxn),BETAofV(NP,mxv),BU1(NP,0:mxv),BU2(NP,0:mxv),
     & sigmaInv(NP,NP,mxv),CUMBDIST(NP,0:mxv),zdev(mxkk,mxn),
     & sigtemp(NP,NP),AsigInv(NP,NP,mxv,mxv),tempaug(mxkk,mxn,mxv),
     & S0N(mxkk,mxn,mxv),S1N(NP,mxkk,mxn,mxv)


      Integer kk,ks,N(mxkk),nvgrid

c   calculate the two parts of the Gaussian multiplier for $n^{1/2}(\hat B_{aug}(v)-B(v))$:


c      print*, 'zdev= ', (zdev(1,i), i=1,5)
c      print*, 'SigmaInv= ', (SigmaInv(1,1,ispot), ispot=1,5)

cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      do 55 ispot=iskip,nvgrid
      DO 50 J=1,NP
         BU1(J,ispot)=0.0
   50 CONTINUE
   55 continue

c      DO 300 ispot=1,nvgrid
      DO 300 ispot=iskip,nvgrid

      do 260 ks=1,kk

c    for time independent covariates
      DO 130 I=1,N(ks)
c      do 130 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 120 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETAofv(J,ispot)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETAofv(J,ispot)*Zt(ks,J,I,1)
  120    CONTINUE
  130  CONTINUE

      DO 240 I=1,N(ks)
         Sx0(I)=0.0
         DO 140 J=1,NP
            Sx1(J,I)=0.0
  140    CONTINUE
         DO 180 L=1,N(ks)
          IF (X(ks,L).GE.X(ks,I)) THEN
           Sx0(I)=Sx0(I)+EXP(BZt(L,1))*zdev(ks,L)
            DO 160 J=1,NP
              Sx1(J,I)=Sx1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)*zdev(ks,L)
  160       CONTINUE
          ENDIF
  180    CONTINUE


         if (S0N(ks,I,ispot).gt.0.00000001) then
         DO 210 J=1,NP
ccnnn
          do 200 mspot=iskip,nvgrid
           tempBU1=0.0
           do 190 K=1,NP
             tempBU1=tempBU1+AsigInv(J,K,ispot,mspot)*(Zt(ks,K,I,1)
     &                             -S1N(K,ks,I,ispot)/S0N(ks,I,ispot))
  190      continue

           tempXBU2=0.0
           do 195 K=1,NP
             tempXBU2=tempXBU2+AsigInv(J,K,ispot,mspot)
     &           *(Sx1(K,I)-Sx0(I)*S1N(K,ks,I,ispot)/S0N(ks,I,ispot))
     &           /S0N(ks,I,ispot)
  195      continue

c        print*, 'ispot, ks, i, temp= ', ispot, ks, i, temp

         BU1(J,mspot)=BU1(J,mspot)+(tempBU1*zdev(ks,i)-tempXBU2)
     &                            *tempaug(ks,i,ispot)

c        if (ispot.eq.1)then
c        print*, 'ispot, ks, i, sum1= ',ispot,ks,i,sum1(1)
c        endif

  200   CONTINUE
  210   continue
ccnnn

        endif

  240 CONTINUE
  260 continue
  300 continue

      nsampa=0
      do ks=1,kk
        nsampa=nsampa+N(ks)
      enddo

c    Note that SigmaInv*nsampa is $\Sigma^{-1}$:  !!!!!

      do J=1,NP
        do ispot=iskip,nvgrid
         CUMBDIST(J,ispot)=BU1(J,ispot)
        enddo
      enddo



C     RETURN
      END



C
C
C     *****************************************************************
C     *                                                               *
C     *                     GAUSSJ         SUBROUTINE                 *
C     *                                                               *
C     *****************************************************************
C
C
      SUBROUTINE GAUSSJ(A,N,NP,B,M,MP)
C      IMPLICIT REAL*8(A-H,O-Z)
      PARAMETER (NMAX=50)
      DIMENSION A(NP,NP),B(NP,MP),IPIV(NMAX),INDXR(NMAX),INDXC(NMAX)
      DO 11 J=1,N
        IPIV(J)=0
11    CONTINUE
      DO 22 I=1,N
        BIG=0.
        DO 13 J=1,N
          IF(IPIV(J).NE.1)THEN
            DO 12 K=1,N
              IF (IPIV(K).EQ.0) THEN
                IF (ABS(A(J,K)).GE.BIG)THEN
                  BIG=ABS(A(J,K))
                  IROW=J
                  ICOL=K
                ENDIF
              ELSE IF (IPIV(K).GT.1) THEN
		print*
c                PAUSE 'Singular matrix'
              ENDIF
12          CONTINUE
          ENDIF
13      CONTINUE
        IPIV(ICOL)=IPIV(ICOL)+1
        IF (IROW.NE.ICOL) THEN
          DO 14 L=1,N
            DUM=A(IROW,L)
            A(IROW,L)=A(ICOL,L)
            A(ICOL,L)=DUM
14        CONTINUE
          DO 15 L=1,M
            DUM=B(IROW,L)
            B(IROW,L)=B(ICOL,L)
            B(ICOL,L)=DUM
15        CONTINUE
        ENDIF
        INDXR(I)=IROW
        INDXC(I)=ICOL
        IF (A(ICOL,ICOL).EQ.0.) print*
c PAUSE 'Singular matrix.'
        PIVINV=1./A(ICOL,ICOL)
        A(ICOL,ICOL)=1.
        DO 16 L=1,N
          A(ICOL,L)=A(ICOL,L)*PIVINV
16      CONTINUE
        DO 17 L=1,M
          B(ICOL,L)=B(ICOL,L)*PIVINV
17      CONTINUE
        DO 21 LL=1,N
          IF(LL.NE.ICOL)THEN
            DUM=A(LL,ICOL)
            A(LL,ICOL)=0.
            DO 18 L=1,N
              A(LL,L)=A(LL,L)-A(ICOL,L)*DUM
18          CONTINUE
            DO 19 L=1,M
              B(LL,L)=B(LL,L)-B(ICOL,L)*DUM
19          CONTINUE
          ENDIF
21      CONTINUE
22    CONTINUE
      DO 24 L=N,1,-1
        IF(INDXR(L).NE.INDXC(L))THEN
          DO 23 K=1,N
            DUM=A(K,INDXR(L))
            A(K,INDXR(L))=A(K,INDXC(L))
            A(K,INDXC(L))=DUM
23        CONTINUE
        ENDIF
24    CONTINUE
      RETURN
      END


C
C     *****************************************************************
C     *                                                               *
C     *                    VARIANCE      SUBROUTINE                   *
C     *                                                               *
C     * for cumulative vaccine efficacy / cumulative coefficient      *
C     *****************************************************************
C
C     we take hatA as F for variance of $B_1(v)$
C     or hatA as F*exp(\hat\beta(v)) for variance of $CV(v)$,
C     where Fin=-(l^{'')(\beta(v)))^{-1} is the output from estpvry.

      SUBROUTINE varcum(vspot,vstep,kk,N,NP,X,ZT,CENSOR,MARK,BETA,
     &       Fin,varcumB,varcumV)
      parameter(mxn=20000,mxkk=1)
C
C      IMPLICIT REAL*8(A-H,O-Z)
      REAL X(mxkk,mxn),CENSOR(mxkk,mxn),zt(mxkk,np,mxn,1),
     & mark(mxkk,mxn),BETA(NP),bzt(mxn,1),S0(mxn),S1(NP,mxn),
     & S2(NP,NP),Fin(NP,NP),F(NP,NP),varcumB(NP,NP),varcumV(NP,NP),
     & FF2(NP,NP)

      Integer kk,ks,N(mxkk)


      DO 80 J=1,NP
            DO 60 K=1,NP
               F(J,K)=0.0
   60       CONTINUE
   80 CONTINUE


      do 405 ks=1,kk

c*******************************************************************
      DO 205 I=1,N(ks)
cctcc
      do 205 k=1,n(ks)
c         BZt(I,k)=0.0
         BZt(I,1)=0.0
         DO 190 J=1,NP
c            BZt(I,k)=BZt(I,k)+BETA(J)*Zt(ks,J,I,k)
            BZt(I,1)=BZt(I,1)+BETA(J)*Zt(ks,J,I,1)
  190    CONTINUE
  205  CONTINUE
c*******************************************************************

      DO 400 I=1,N(ks)
      if((mark(ks,i).gt.(vspot-vstep)).and.(mark(ks,i).le.vspot))then

         S0(I)=0.0
         DO 220 J=1,NP
            S1(J,I)=0.0
            DO 210 K=1,NP
               S2(J,K)=0.0
  210       CONTINUE
  220    CONTINUE

cctcc
         DO 300 L=1,N(ks)
            IF (X(ks,L).GE.X(ks,I)) THEN
c               S0(I)=S0(I)+EXP(BZt(L,i))
               S0(I)=S0(I)+EXP(BZt(L,1))
            DO 280 J=1,NP
c               S1(J,I)=S1(J,I)+EXP(BZt(L,i))*Zt(ks,J,L,i)
               S1(J,I)=S1(J,I)+EXP(BZt(L,1))*Zt(ks,J,L,1)
               DO 260 K=1,NP
c               S2(J,K)=S2(J,K)+EXP(BZt(L,i))*Zt(ks,J,L,i)*Zt(ks,K,L,i)
               S2(J,K)=S2(J,K)+EXP(BZt(L,1))*Zt(ks,J,L,1)*Zt(ks,K,L,1)
  260          CONTINUE
  280       CONTINUE
            ENDIF
  300    CONTINUE

         DO 380 J=1,NP
            DO 360 K=1,NP
               F(J,K)=F(J,K)+CENSOR(ks,I)*(S2(J,K)/S0(I)
     &                -S1(J,I)*S1(K,I)/S0(I)**2)
  360       CONTINUE
  380    CONTINUE

      endif
  400 CONTINUE
  405 continue


C     the variance of \hat\beta(v) is var in the following

      call ATIMEB(Fin,F,FF2,NP,NP,NP,NP,NP,NP)
      call ATIMEB(FF2,Fin,varcumB,NP,NP,NP,NP,NP,NP)


      DO 800 J=1,NP
         DO 700 K=1,NP
         varcumV(J,K)=exp(2.*beta(1))*varcumB(J,K)
  700    CONTINUE
  800 CONTINUE
C     RETURN
      END






******************************************************************
*  Modified to accommodate stratas
*
*                      ESTPLOGIT       SUBROUTINE
*
******************************************************************
      SUBROUTINE estplogit(KK,N,NPL,Z,R,D,PSI,FVAR)
      parameter (mxn=20000)
     &
      INTEGER KK,N(KK),NPL
      real Z(KK,NPL,mxn),R(KK,mxn),D(KK,mxn),PSI(KK,NPL),
     &     UL(NPL),UL2(NPL),FL(NPL,NPL),FVAR(KK,NPL,NPL),TZ(mxn),P(mxn)

*     R = R_i and D = D_i <-- input
*     UL = score function
*     FL = -second derivative
*     TZ = theta * (1, Z)

c      print*, 'Z,R =', (Z(1,j,1), j=1,2), R(1,1)

      DO 900 ks=1,KK

c         DO 50 J=1,NPL
c          PSI(ks,J)=0.0
c  50  CONTINUE

      DO 850 iter=1, 10

      DO 80 J=1,NPL
         UL(J)=0.0
         UL2(J)=0.0
            DO 60 K=1,NPL
               FL(J,K)=0.0
   60       CONTINUE
   80 CONTINUE
C
      DO 200 I=1,N(ks)
         TZ(I)=0.0
         DO 180 J=1,NPL
            TZ(I)=TZ(I)+PSI(ks,J)*Z(ks,J,I)
  180    CONTINUE
         P(I)=exp(TZ(I))/(1.0+exp(TZ(I)))
  200 CONTINUE
C
      DO 400 I=1,N(ks)
        DO 380 J=1,NPL
c          UL(J)=UL(J)+(R(ks,I)*D(ks,I)*(1.0-P(I))-(1.0-R(ks,I))*P(I))
          UL(J)=UL(J)+(R(ks,I)*D(ks,I)*(1.0-P(I))-(1.0-R(ks,I))*D(ks,I)
     $          *P(I))*Z(ks,J,I)
          UL2(J)=UL(J)
          DO 360 K=1,NPL
           FL(J,K)=FL(J,K)+(R(ks,I)*D(ks,I)+(1.0-R(ks,I))*D(ks,I))*P(I)
     $                 *(1.0-P(I))*Z(ks,J,I)*Z(ks,K,I)
  360     CONTINUE
  380   CONTINUE
  400 CONTINUE

c      print*, 'UL= ', UL

      CALL GAUSSJ(FL,NPL,NPL,UL,1,1)
C     after CALL GAUSS, F now is replaced by its inverse matrix
C     and U now is replaced by F^{-1}U. F^{-1} would also be a
C     estimate of covariance matrix of \hat\theta at the output.
C     the following is the newton napson method to get mle:

      DO 800 J=1,NPL
         PSI(ks,J)=PSI(ks,J)+UL(J)
  800 CONTINUE
  850 CONTINUE

      DO 855 J=1,NPL
      DO 855 K=1,NPL
        FVAR(ks,J,K)=FL(J,K)
  855 CONTINUE


  900 CONTINUE

C     RETURN
      END




cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c  indexes the array arrin, outputs the array indx
cccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      subroutine indexx(n,arrin,indx)
      parameter (mxb=100)
      real arrin(mxb)
      integer indx(mxb)
      do 11 j=1,n
         indx(j)=j
 11   continue
      l=n/2+1
      ir=n
 10   continue
         if(l.gt.1)then
            l=l-1
            indxt=indx(l)
            q=arrin(indxt)
         else
            indxt=indx(ir)
            q=arrin(indxt)
            indx(ir)=indx(1)
            ir=ir-1
            if(ir.eq.1)then
               indx(1)=indxt
               return
            endif
         endif
         i=l
         j=l+l
 20      if(j.le.ir)then
            if(j.lt.ir)then
               if(arrin(indx(j)).lt.arrin(indx(j+1)))j=j+1
            endif
            if(q.lt.arrin(indx(j)))then
               indx(i)=indx(j)
               i=j
               j=j+j
            else
               j=ir+1
            endif
         go to 20
         endif
         indx(i)=indxt
      go to 10
      end


c****************************************************************************

      SUBROUTINE sort(n,arr)
      parameter (mxb=100)
      INTEGER n,M,NSTACK
      REAL arr(mxb)
      PARAMETER (M=7,NSTACK=50)
      INTEGER i,ir,j,jstack,k,l,istack(NSTACK)
      REAL a,temp
      jstack=0
      l=1
      ir=n
1     if(ir-l.lt.M)then
        do 12 j=l+1,ir
          a=arr(j)
          do 11 i=j-1,l,-1
            if(arr(i).le.a)goto 2
            arr(i+1)=arr(i)
11        continue
          i=l-1
2         arr(i+1)=a
12      continue
        if(jstack.eq.0)return
        ir=istack(jstack)
        l=istack(jstack-1)
        jstack=jstack-2
      else
        k=(l+ir)/2
        temp=arr(k)
        arr(k)=arr(l+1)
        arr(l+1)=temp
        if(arr(l).gt.arr(ir))then
          temp=arr(l)
          arr(l)=arr(ir)
          arr(ir)=temp
        endif
        if(arr(l+1).gt.arr(ir))then
          temp=arr(l+1)
          arr(l+1)=arr(ir)
          arr(ir)=temp
        endif
        if(arr(l).gt.arr(l+1))then
          temp=arr(l)
          arr(l)=arr(l+1)
          arr(l+1)=temp
        endif
        i=l+1
        j=ir
        a=arr(l+1)
3       continue
          i=i+1
        if(arr(i).lt.a)goto 3
4       continue
          j=j-1
        if(arr(j).gt.a)goto 4
        if(j.lt.i)goto 5
        temp=arr(i)
        arr(i)=arr(j)
        arr(j)=temp
        goto 3
5       arr(l+1)=arr(j)
        arr(j)=a
        jstack=jstack+2
        if(jstack.gt.NSTACK) print* 
cpause 'NSTACK too small in sort'
        if(ir-i+1.ge.j-l)then
          istack(jstack)=ir
          istack(jstack-1)=i
          ir=j-1
        else
          istack(jstack)=j-1
          istack(jstack-1)=l
          l=i
        endif
      endif
      goto 1
      END

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c    cxv is an estimate of the variance $\hat\rho^2_{CV}(v)$
c    or $\hat\rho^2_{B_1}(v)$
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

      SUBROUTINE CVALUE(a,b,iskip,ispan,ngrid,cxv,zdev,CSUPa,CSUPb,
     $ TSUP1,TSQR1,TSUP2,TSQR2,TSUP1m,TSQR1m,TSUP2m,TSQR2m)
      parameter(mxv=200)

      REAL cxv(0:mxv),zdev(0:mxv),WA(0:mxv),WB(0:mxv),BA(0:mxv)
      INTEGER ngrid,iskip,ispan

      cxv(0)=0.
      WA(0)=0.
      WB(0)=0.

      CSUPa=0.
      CSUPb=0.
      TSUP1=0.
      TSQR1=0.
      TSUP2=0.
      TSQR2=0.

      TSUP1m=-999.
      TSQR1m=0.
      TSUP2m=-999.
      TSQR2m=0.

      vstep=(b-a)/float(ngrid)

      do ispot=1,ngrid
      vspot=a+float(ispot)*vstep

c     generate Wiener process and Brownian motion on (0,.5)
c      diffa=cxv(ispot)/(cxv(ispot)+cxv(ngrid))
c     $ -cxv(ispot-1)/(cxv(ispot-1)+cxv(ngrid))
c      WA(ispot)=WA(ispot-1)+sqrt(diffa)*zdev(ispot-1)
c      BA(ispot)=WA(ispot)-cxv(ispot)/(cxv(ispot)+cxv(ngrid))
c     $ *(WA(ngrid)+sqrt(.5)*zdev(ngrid))

ccccccccccccccccccccccccccc
c     the following is the Brownian bridge used for uniform confidence band
c     of Cumulative vaccine efficacy and TSUPa (TSUPb) is for the critical value $u_\alpha$:
ccccccccccccccccccccccccccc

      diffa=cxv(ispot)-cxv(ispot-1)
      WA(ispot)=WA(ispot-1)+sqrt(diffa)*zdev(ispot-1)
      BA(ispot)=WA(ispot)*cxv(ngrid)**.5/(cxv(ispot)+cxv(ngrid))


c     calculate the supremum and square integration of Brownian Bridge on (0,.5)
      if((ispot.ge.iskip).and.(abs(BA(ispot)).gt.CSUPa))then
      CSUPa=abs(BA(ispot))
      endif

c      if(ispot.ge.iskip)then
c      TSQRa=TSQRa+(BA(ispot))**2.*diffa
c      endif

ccccccccccccccccccccccccccc
c     the following is the Wiener process used for testing hypothesis $H_1$:
ccccccccccccccccccccccccccc

      diffb=cxv(ispot)/cxv(ngrid)-cxv(ispot-1)/cxv(ngrid)
      WB(ispot)=WB(ispot-1)+sqrt(diffb)*zdev(ispot-1)

c      if(ispot.le.(ngrid-1))then
c            print*, 'diffb= ',diffb, '  zdev= ',zdev(1)
c      endif

c     calculate the supremum and square integration of Wiener Process 0n (0,1)
      if((ispot.ge.iskip).and.(abs(WB(ispot)).gt.TSUP1))then
      TSUP1=abs(WB(ispot))
      endif
      if((ispot.ge.iskip).and.(WB(ispot).gt.TSUP1m))then
      TSUP1m=WB(ispot)
      endif

      if(ispot.ge.iskip)then
      TSQR1=TSQR1+(WB(ispot))**2.*diffb
      endif
      if(ispot.ge.iskip)then
      TSQR1m=TSQR1m+WB(ispot)*diffb
      endif

      enddo

ccccccccccccccccccccccccccc
c     the following is to get the critical value for the uniforma confidence interval
c     over a smaller set of values:
ccccccccccccccccccccccccccc

      do ispot=ispan,ngrid,ispan
      if(abs(BA(ispot)).gt.CSUPb)then
      CSUPb=abs(BA(ispot))
      endif
      enddo


ccccccccccccccccccccccccccc
c     the following is the process used for testing hypothesis $H_2$:
ccccccccccccccccccccccccccc

      do ispot=1,ngrid
      vspot=a+float(ispot)*vstep
      diffb=cxv(ispot)/cxv(ngrid)-cxv(ispot-1)/cxv(ngrid)
      WB(ispot)=WB(ispot)-(vspot-a)/(b-a)*WB(ngrid)
c !*!
      WB(ispot)=WB(ispot)/(vspot-a)

      if((ispot.ge.iskip).and.(abs(WB(ispot)).gt.TSUP2))then
      TSUP2=abs(WB(ispot))
      TSQR2m=TSQR2m+WB(ispot)*diffb
      endif
      enddo

c      print*,'cxv =', (cxv(k),k=1,ngrid)
c      print*, (BA(k),k=1,ngrid)
c      print*, (WA(k),k=1,ngrid)
      end

c****************************************************************************



c****************************************************************************
c uniker is (1/h)K((t_k-t)/h) \delta where K is uniform kernel
c calculate (1/h)*K((t_k-t)/h), K is uniform kernel on [-1,1]
c
c****************************************************************************

       function uniker(tk,tvalue,hband,delt)
       real tk, tvalue, hband, delt, uniker
       if (abs(tk-tvalue).lt. hband)then
       uniker=1.0/(2.*hband)*delt
       else
       uniker=0.0
       endif
       end

c****************************************************************************
c calculate (1/h)*K((t_k-t)/h), K is normal kernel
c (.3989422804) = 1/sqrt(2\pi)
c normker is (1/h)K((t_k-t)/h) \delta where K is normal kernel
c****************************************************************************

       function normker(tk,tvalue,hband,delt)
       real tk, tvalue, hband, delt, normker
       normker=(1.0/hband)*delt*(.3989422804)
     $ *exp(-.5*((tk-tvalue)/hband)**2)
       end

c****************************************************************************
c calculate (1/h)*K((t_k-t)/h), K is Epanechnikov  kernel
c K(u)=3/4(1-u^2), -1<u<1
c****************************************************************************

       function Epanker(tk,tvalue,hband,delt)
       real tk, tvalue, hband, delt, Epanker
       if (abs(tk-tvalue).lt. hband)then
       Epanker=3.0/(4.*hband)*delt*(1-((tk-tvalue)/hband)**2)
       else
       Epanker=0.0
       endif
       end
